Class: Solifyn::BillingApi
- Inherits:
-
Object
- Object
- Solifyn::BillingApi
- Defined in:
- lib/solifyn/api/billing_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#billing_get_plans(opts = {}) ⇒ nil
Get Platform Plans Returns all available platform subscription plans with fees and features.
-
#billing_get_plans_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Platform Plans Returns all available platform subscription plans with fees and features.
-
#initialize(api_client = ApiClient.default) ⇒ BillingApi
constructor
A new instance of BillingApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BillingApi
Returns a new instance of BillingApi.
19 20 21 |
# File 'lib/solifyn/api/billing_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/billing_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#billing_get_plans(opts = {}) ⇒ nil
Get Platform Plans Returns all available platform subscription plans with fees and features.
26 27 28 29 |
# File 'lib/solifyn/api/billing_api.rb', line 26 def billing_get_plans(opts = {}) billing_get_plans_with_http_info(opts) nil end |
#billing_get_plans_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Platform Plans Returns all available platform subscription plans with fees and features.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/solifyn/api/billing_api.rb', line 35 def billing_get_plans_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingApi.billing_get_plans ...' end # resource path local_var_path = '/v1/billing/plans' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"BillingApi.billing_get_plans", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingApi#billing_get_plans\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |