Class: Solifyn::BrandsApi
- Inherits:
-
Object
- Object
- Solifyn::BrandsApi
- Defined in:
- lib/solifyn/api/brands_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#brands_create(brand_create, opts = {}) ⇒ Brand
Create Brand Add a new brand identity under the current active business.
-
#brands_create_with_http_info(brand_create, opts = {}) ⇒ Array<(Brand, Integer, Hash)>
Create Brand Add a new brand identity under the current active business.
-
#brands_get(id, opts = {}) ⇒ Brand
Retrieve Brand Retrieve details of a brand identity by ID.
-
#brands_get_with_http_info(id, opts = {}) ⇒ Array<(Brand, Integer, Hash)>
Retrieve Brand Retrieve details of a brand identity by ID.
-
#brands_list(opts = {}) ⇒ Array<Brand>
List Brands Retrieve all brands associated with the current business context.
-
#brands_list_with_http_info(opts = {}) ⇒ Array<(Array<Brand>, Integer, Hash)>
List Brands Retrieve all brands associated with the current business context.
-
#brands_update(id, brand_update, opts = {}) ⇒ Brand
Update Brand Update website, logo, description, or statement descriptors of a brand.
-
#brands_update_with_http_info(id, brand_update, opts = {}) ⇒ Array<(Brand, Integer, Hash)>
Update Brand Update website, logo, description, or statement descriptors of a brand.
-
#initialize(api_client = ApiClient.default) ⇒ BrandsApi
constructor
A new instance of BrandsApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/brands_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#brands_create(brand_create, opts = {}) ⇒ Brand
Create Brand Add a new brand identity under the current active business.
27 28 29 30 |
# File 'lib/solifyn/api/brands_api.rb', line 27 def brands_create(brand_create, opts = {}) data, _status_code, _headers = brands_create_with_http_info(brand_create, opts) data end |
#brands_create_with_http_info(brand_create, opts = {}) ⇒ Array<(Brand, Integer, Hash)>
Create Brand Add a new brand identity under the current active business.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/solifyn/api/brands_api.rb', line 37 def brands_create_with_http_info(brand_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BrandsApi.brands_create ...' end # verify the required parameter 'brand_create' is set if @api_client.config.client_side_validation && brand_create.nil? fail ArgumentError, "Missing the required parameter 'brand_create' when calling BrandsApi.brands_create" end # resource path local_var_path = '/v1/user/brand' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(brand_create) # return_type return_type = opts[:debug_return_type] || 'Brand' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BrandsApi.brands_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BrandsApi#brands_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#brands_get(id, opts = {}) ⇒ Brand
Retrieve Brand Retrieve details of a brand identity by ID.
95 96 97 98 |
# File 'lib/solifyn/api/brands_api.rb', line 95 def brands_get(id, opts = {}) data, _status_code, _headers = brands_get_with_http_info(id, opts) data end |
#brands_get_with_http_info(id, opts = {}) ⇒ Array<(Brand, Integer, Hash)>
Retrieve Brand Retrieve details of a brand identity by ID.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/solifyn/api/brands_api.rb', line 105 def brands_get_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BrandsApi.brands_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling BrandsApi.brands_get" end # resource path local_var_path = '/v1/user/brand/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Brand' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BrandsApi.brands_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BrandsApi#brands_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#brands_list(opts = {}) ⇒ Array<Brand>
List Brands Retrieve all brands associated with the current business context.
157 158 159 160 |
# File 'lib/solifyn/api/brands_api.rb', line 157 def brands_list(opts = {}) data, _status_code, _headers = brands_list_with_http_info(opts) data end |
#brands_list_with_http_info(opts = {}) ⇒ Array<(Array<Brand>, Integer, Hash)>
List Brands Retrieve all brands associated with the current business context.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/solifyn/api/brands_api.rb', line 166 def brands_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BrandsApi.brands_list ...' end # resource path local_var_path = '/v1/user/brands' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Brand>' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BrandsApi.brands_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BrandsApi#brands_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#brands_update(id, brand_update, opts = {}) ⇒ Brand
Update Brand Update website, logo, description, or statement descriptors of a brand.
216 217 218 219 |
# File 'lib/solifyn/api/brands_api.rb', line 216 def brands_update(id, brand_update, opts = {}) data, _status_code, _headers = brands_update_with_http_info(id, brand_update, opts) data end |
#brands_update_with_http_info(id, brand_update, opts = {}) ⇒ Array<(Brand, Integer, Hash)>
Update Brand Update website, logo, description, or statement descriptors of a brand.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/solifyn/api/brands_api.rb', line 227 def brands_update_with_http_info(id, brand_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BrandsApi.brands_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling BrandsApi.brands_update" end # verify the required parameter 'brand_update' is set if @api_client.config.client_side_validation && brand_update.nil? fail ArgumentError, "Missing the required parameter 'brand_update' when calling BrandsApi.brands_update" end # resource path local_var_path = '/v1/user/brand/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(brand_update) # return_type return_type = opts[:debug_return_type] || 'Brand' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BrandsApi.brands_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BrandsApi#brands_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |