Class: Solifyn::Business
- Inherits:
-
Object
- Object
- Solifyn::Business
- Defined in:
- lib/solifyn/models/business.rb
Instance Attribute Summary collapse
-
#affiliate_instructions ⇒ Object
Markdown instructions for affiliates.
-
#created_at ⇒ Object
Timestamp when the business record was created.
-
#default_currency ⇒ Object
The default currency of the business.
-
#description ⇒ Object
A description explaining what the business does.
-
#id ⇒ Object
The unique business ID.
-
#logo_url ⇒ Object
Brand logo image URL resolved from primary brand.
-
#member_count ⇒ Object
Total members/customers under this business.
-
#merchant_id ⇒ Object
The merchant owner ID.
-
#metadata ⇒ Object
Custom key-value metadata.
-
#published_reviews_count ⇒ Object
Number of published user reviews on Whop.
-
#route ⇒ Object
Whop friendly URL path route.
-
#send_customer_emails ⇒ Object
Whether auto-emails are enabled for customers.
-
#social_links ⇒ Object
Social links setup.
-
#target_audience ⇒ Object
The target audience description.
-
#title ⇒ Object
Title or name of the business.
-
#updated_at ⇒ Object
Timestamp when the business record was last updated.
-
#verified ⇒ Object
Whether the business has been KYC-verified on Whop.
-
#whop_created_at ⇒ Object
Whop account creation timestamp.
-
#whop_id ⇒ Object
The Whop Company ID.
-
#whop_updated_at ⇒ Object
Whop account last updated timestamp.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Business
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Business
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/solifyn/models/business.rb', line 143 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::Business` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::Business`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'whop_id') self.whop_id = attributes[:'whop_id'] else self.whop_id = nil end if attributes.key?(:'merchant_id') self.merchant_id = attributes[:'merchant_id'] else self.merchant_id = nil end if attributes.key?(:'verified') self.verified = attributes[:'verified'] else self.verified = nil end if attributes.key?(:'send_customer_emails') self.send_customer_emails = attributes[:'send_customer_emails'] else self.send_customer_emails = nil end if attributes.key?(:'member_count') self.member_count = attributes[:'member_count'] else self.member_count = nil end if attributes.key?(:'route') self.route = attributes[:'route'] end if attributes.key?(:'default_currency') self.default_currency = attributes[:'default_currency'] else self.default_currency = nil end if attributes.key?(:'published_reviews_count') self.published_reviews_count = attributes[:'published_reviews_count'] else self.published_reviews_count = nil end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'target_audience') self.target_audience = attributes[:'target_audience'] end if attributes.key?(:'social_links') self. = attributes[:'social_links'] end if attributes.key?(:'affiliate_instructions') self.affiliate_instructions = attributes[:'affiliate_instructions'] end if attributes.key?(:'whop_created_at') self.whop_created_at = attributes[:'whop_created_at'] end if attributes.key?(:'whop_updated_at') self.whop_updated_at = attributes[:'whop_updated_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'logo_url') self.logo_url = attributes[:'logo_url'] end end |
Instance Attribute Details
#affiliate_instructions ⇒ Object
Markdown instructions for affiliates
61 62 63 |
# File 'lib/solifyn/models/business.rb', line 61 def affiliate_instructions @affiliate_instructions end |
#created_at ⇒ Object
Timestamp when the business record was created
70 71 72 |
# File 'lib/solifyn/models/business.rb', line 70 def created_at @created_at end |
#default_currency ⇒ Object
The default currency of the business
46 47 48 |
# File 'lib/solifyn/models/business.rb', line 46 def default_currency @default_currency end |
#description ⇒ Object
A description explaining what the business does
25 26 27 |
# File 'lib/solifyn/models/business.rb', line 25 def description @description end |
#id ⇒ Object
The unique business ID
19 20 21 |
# File 'lib/solifyn/models/business.rb', line 19 def id @id end |
#logo_url ⇒ Object
Brand logo image URL resolved from primary brand
76 77 78 |
# File 'lib/solifyn/models/business.rb', line 76 def logo_url @logo_url end |
#member_count ⇒ Object
Total members/customers under this business
40 41 42 |
# File 'lib/solifyn/models/business.rb', line 40 def member_count @member_count end |
#merchant_id ⇒ Object
The merchant owner ID
31 32 33 |
# File 'lib/solifyn/models/business.rb', line 31 def merchant_id @merchant_id end |
#metadata ⇒ Object
Custom key-value metadata
52 53 54 |
# File 'lib/solifyn/models/business.rb', line 52 def @metadata end |
#published_reviews_count ⇒ Object
Number of published user reviews on Whop
49 50 51 |
# File 'lib/solifyn/models/business.rb', line 49 def published_reviews_count @published_reviews_count end |
#route ⇒ Object
Whop friendly URL path route
43 44 45 |
# File 'lib/solifyn/models/business.rb', line 43 def route @route end |
#send_customer_emails ⇒ Object
Whether auto-emails are enabled for customers
37 38 39 |
# File 'lib/solifyn/models/business.rb', line 37 def send_customer_emails @send_customer_emails end |
#social_links ⇒ Object
Social links setup
58 59 60 |
# File 'lib/solifyn/models/business.rb', line 58 def @social_links end |
#target_audience ⇒ Object
The target audience description
55 56 57 |
# File 'lib/solifyn/models/business.rb', line 55 def target_audience @target_audience end |
#title ⇒ Object
Title or name of the business
22 23 24 |
# File 'lib/solifyn/models/business.rb', line 22 def title @title end |
#updated_at ⇒ Object
Timestamp when the business record was last updated
73 74 75 |
# File 'lib/solifyn/models/business.rb', line 73 def updated_at @updated_at end |
#verified ⇒ Object
Whether the business has been KYC-verified on Whop
34 35 36 |
# File 'lib/solifyn/models/business.rb', line 34 def verified @verified end |
#whop_created_at ⇒ Object
Whop account creation timestamp
64 65 66 |
# File 'lib/solifyn/models/business.rb', line 64 def whop_created_at @whop_created_at end |
#whop_id ⇒ Object
The Whop Company ID
28 29 30 |
# File 'lib/solifyn/models/business.rb', line 28 def whop_id @whop_id end |
#whop_updated_at ⇒ Object
Whop account last updated timestamp
67 68 69 |
# File 'lib/solifyn/models/business.rb', line 67 def whop_updated_at @whop_updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/solifyn/models/business.rb', line 395 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
105 106 107 |
# File 'lib/solifyn/models/business.rb', line 105 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/solifyn/models/business.rb', line 79 def self.attribute_map { :'id' => :'id', :'title' => :'title', :'description' => :'description', :'whop_id' => :'whopId', :'merchant_id' => :'merchantId', :'verified' => :'verified', :'send_customer_emails' => :'sendCustomerEmails', :'member_count' => :'memberCount', :'route' => :'route', :'default_currency' => :'defaultCurrency', :'published_reviews_count' => :'publishedReviewsCount', :'metadata' => :'metadata', :'target_audience' => :'targetAudience', :'social_links' => :'socialLinks', :'affiliate_instructions' => :'affiliateInstructions', :'whop_created_at' => :'whopCreatedAt', :'whop_updated_at' => :'whopUpdatedAt', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'logo_url' => :'logoUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/solifyn/models/business.rb', line 371 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
136 137 138 139 |
# File 'lib/solifyn/models/business.rb', line 136 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/solifyn/models/business.rb', line 110 def self.openapi_types { :'id' => :'String', :'title' => :'String', :'description' => :'String', :'whop_id' => :'String', :'merchant_id' => :'String', :'verified' => :'Boolean', :'send_customer_emails' => :'Boolean', :'member_count' => :'Float', :'route' => :'String', :'default_currency' => :'String', :'published_reviews_count' => :'Float', :'metadata' => :'Object', :'target_audience' => :'String', :'social_links' => :'Object', :'affiliate_instructions' => :'String', :'whop_created_at' => :'Time', :'whop_updated_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time', :'logo_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/solifyn/models/business.rb', line 331 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && title == o.title && description == o.description && whop_id == o.whop_id && merchant_id == o.merchant_id && verified == o.verified && send_customer_emails == o.send_customer_emails && member_count == o.member_count && route == o.route && default_currency == o.default_currency && published_reviews_count == o.published_reviews_count && == o. && target_audience == o.target_audience && == o. && affiliate_instructions == o.affiliate_instructions && whop_created_at == o.whop_created_at && whop_updated_at == o.whop_updated_at && created_at == o.created_at && updated_at == o.updated_at && logo_url == o.logo_url end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/solifyn/models/business.rb', line 466 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
358 359 360 |
# File 'lib/solifyn/models/business.rb', line 358 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
364 365 366 |
# File 'lib/solifyn/models/business.rb', line 364 def hash [id, title, description, whop_id, merchant_id, verified, send_customer_emails, member_count, route, default_currency, published_reviews_count, , target_audience, , affiliate_instructions, whop_created_at, whop_updated_at, created_at, updated_at, logo_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/solifyn/models/business.rb', line 261 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @whop_id.nil? invalid_properties.push('invalid value for "whop_id", whop_id cannot be nil.') end if @merchant_id.nil? invalid_properties.push('invalid value for "merchant_id", merchant_id cannot be nil.') end if @verified.nil? invalid_properties.push('invalid value for "verified", verified cannot be nil.') end if @send_customer_emails.nil? invalid_properties.push('invalid value for "send_customer_emails", send_customer_emails cannot be nil.') end if @member_count.nil? invalid_properties.push('invalid value for "member_count", member_count cannot be nil.') end if @default_currency.nil? invalid_properties.push('invalid value for "default_currency", default_currency cannot be nil.') end if @published_reviews_count.nil? invalid_properties.push('invalid value for "published_reviews_count", published_reviews_count cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
442 443 444 |
# File 'lib/solifyn/models/business.rb', line 442 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/solifyn/models/business.rb', line 448 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
436 437 438 |
# File 'lib/solifyn/models/business.rb', line 436 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/solifyn/models/business.rb', line 313 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @title.nil? return false if @whop_id.nil? return false if @merchant_id.nil? return false if @verified.nil? return false if @send_customer_emails.nil? return false if @member_count.nil? return false if @default_currency.nil? return false if @published_reviews_count.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |