Class: Solifyn::BusinessesApi
- Inherits:
-
Object
- Object
- Solifyn::BusinessesApi
- Defined in:
- lib/solifyn/api/businesses_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#businesses_billing_history(opts = {}) ⇒ nil
Get Platform Billing History Retrieve history of SaaS subscription payments paid by this business to the platform.
-
#businesses_billing_history_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Platform Billing History Retrieve history of SaaS subscription payments paid by this business to the platform.
-
#initialize(api_client = ApiClient.default) ⇒ BusinessesApi
constructor
A new instance of BusinessesApi.
-
#merchants_generate_api_keys(opts = {}) ⇒ WhopApiKeysRotation
Rotate Whop API Keys Generate and sync a new Whop Child Company API key (restricted to business owners).
-
#merchants_generate_api_keys_with_http_info(opts = {}) ⇒ Array<(WhopApiKeysRotation, Integer, Hash)>
Rotate Whop API Keys Generate and sync a new Whop Child Company API key (restricted to business owners).
-
#merchants_update_page(user_theme_update, opts = {}) ⇒ UserPage
Update Page configuration Modify store page content configs, banner images, or avatar details.
-
#merchants_update_page_with_http_info(user_theme_update, opts = {}) ⇒ Array<(UserPage, Integer, Hash)>
Update Page configuration Modify store page content configs, banner images, or avatar details.
-
#merchants_update_settings(user_settings_update, opts = {}) ⇒ UserSettings
Update Merchant Settings Update profile parameters, SEO, Google analytics, and email notification properties.
-
#merchants_update_settings_with_http_info(user_settings_update, opts = {}) ⇒ Array<(UserSettings, Integer, Hash)>
Update Merchant Settings Update profile parameters, SEO, Google analytics, and email notification properties.
-
#merchants_update_theme(user_theme_update, opts = {}) ⇒ UserTheme
Update Theme Update colors, fonts, avatar, or banner settings for the store.
-
#merchants_update_theme_with_http_info(user_theme_update, opts = {}) ⇒ Array<(UserTheme, Integer, Hash)>
Update Theme Update colors, fonts, avatar, or banner settings for the store.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BusinessesApi
Returns a new instance of BusinessesApi.
19 20 21 |
# File 'lib/solifyn/api/businesses_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/businesses_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#businesses_billing_history(opts = {}) ⇒ nil
Get Platform Billing History Retrieve history of SaaS subscription payments paid by this business to the platform.
26 27 28 29 |
# File 'lib/solifyn/api/businesses_api.rb', line 26 def businesses_billing_history(opts = {}) businesses_billing_history_with_http_info(opts) nil end |
#businesses_billing_history_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Platform Billing History Retrieve history of SaaS subscription payments paid by this business to the platform.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/solifyn/api/businesses_api.rb', line 35 def businesses_billing_history_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BusinessesApi.businesses_billing_history ...' end # resource path local_var_path = '/v1/user/billing/history' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BusinessesApi.businesses_billing_history", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BusinessesApi#businesses_billing_history\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#merchants_generate_api_keys(opts = {}) ⇒ WhopApiKeysRotation
Rotate Whop API Keys Generate and sync a new Whop Child Company API key (restricted to business owners).
81 82 83 84 |
# File 'lib/solifyn/api/businesses_api.rb', line 81 def merchants_generate_api_keys(opts = {}) data, _status_code, _headers = merchants_generate_api_keys_with_http_info(opts) data end |
#merchants_generate_api_keys_with_http_info(opts = {}) ⇒ Array<(WhopApiKeysRotation, Integer, Hash)>
Rotate Whop API Keys Generate and sync a new Whop Child Company API key (restricted to business owners).
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/solifyn/api/businesses_api.rb', line 90 def merchants_generate_api_keys_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BusinessesApi.merchants_generate_api_keys ...' end # resource path local_var_path = '/v1/user/whop-api-keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WhopApiKeysRotation' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BusinessesApi.merchants_generate_api_keys", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BusinessesApi#merchants_generate_api_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#merchants_update_page(user_theme_update, opts = {}) ⇒ UserPage
Update Page configuration Modify store page content configs, banner images, or avatar details.
139 140 141 142 |
# File 'lib/solifyn/api/businesses_api.rb', line 139 def merchants_update_page(user_theme_update, opts = {}) data, _status_code, _headers = merchants_update_page_with_http_info(user_theme_update, opts) data end |
#merchants_update_page_with_http_info(user_theme_update, opts = {}) ⇒ Array<(UserPage, Integer, Hash)>
Update Page configuration Modify store page content configs, banner images, or avatar details.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/solifyn/api/businesses_api.rb', line 149 def merchants_update_page_with_http_info(user_theme_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BusinessesApi.merchants_update_page ...' end # verify the required parameter 'user_theme_update' is set if @api_client.config.client_side_validation && user_theme_update.nil? fail ArgumentError, "Missing the required parameter 'user_theme_update' when calling BusinessesApi.merchants_update_page" end # resource path local_var_path = '/v1/user/page' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(user_theme_update) # return_type return_type = opts[:debug_return_type] || 'UserPage' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BusinessesApi.merchants_update_page", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BusinessesApi#merchants_update_page\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#merchants_update_settings(user_settings_update, opts = {}) ⇒ UserSettings
Update Merchant Settings Update profile parameters, SEO, Google analytics, and email notification properties.
207 208 209 210 |
# File 'lib/solifyn/api/businesses_api.rb', line 207 def merchants_update_settings(user_settings_update, opts = {}) data, _status_code, _headers = merchants_update_settings_with_http_info(user_settings_update, opts) data end |
#merchants_update_settings_with_http_info(user_settings_update, opts = {}) ⇒ Array<(UserSettings, Integer, Hash)>
Update Merchant Settings Update profile parameters, SEO, Google analytics, and email notification properties.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/solifyn/api/businesses_api.rb', line 217 def merchants_update_settings_with_http_info(user_settings_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BusinessesApi.merchants_update_settings ...' end # verify the required parameter 'user_settings_update' is set if @api_client.config.client_side_validation && user_settings_update.nil? fail ArgumentError, "Missing the required parameter 'user_settings_update' when calling BusinessesApi.merchants_update_settings" end # resource path local_var_path = '/v1/user/settings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(user_settings_update) # return_type return_type = opts[:debug_return_type] || 'UserSettings' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BusinessesApi.merchants_update_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BusinessesApi#merchants_update_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#merchants_update_theme(user_theme_update, opts = {}) ⇒ UserTheme
Update Theme Update colors, fonts, avatar, or banner settings for the store.
275 276 277 278 |
# File 'lib/solifyn/api/businesses_api.rb', line 275 def merchants_update_theme(user_theme_update, opts = {}) data, _status_code, _headers = merchants_update_theme_with_http_info(user_theme_update, opts) data end |
#merchants_update_theme_with_http_info(user_theme_update, opts = {}) ⇒ Array<(UserTheme, Integer, Hash)>
Update Theme Update colors, fonts, avatar, or banner settings for the store.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/solifyn/api/businesses_api.rb', line 285 def merchants_update_theme_with_http_info(user_theme_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BusinessesApi.merchants_update_theme ...' end # verify the required parameter 'user_theme_update' is set if @api_client.config.client_side_validation && user_theme_update.nil? fail ArgumentError, "Missing the required parameter 'user_theme_update' when calling BusinessesApi.merchants_update_theme" end # resource path local_var_path = '/v1/user/theme' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(user_theme_update) # return_type return_type = opts[:debug_return_type] || 'UserTheme' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BusinessesApi.merchants_update_theme", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BusinessesApi#merchants_update_theme\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |