Class: Solifyn::DiscordIntegrationApi

Inherits:
Object
  • Object
show all
Defined in:
lib/solifyn/api/discord_integration_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DiscordIntegrationApi

Returns a new instance of DiscordIntegrationApi.



19
20
21
# File 'lib/solifyn/api/discord_integration_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/solifyn/api/discord_integration_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#discord_get_install_url(opts = {}) ⇒ nil

Get Discord Bot Installation URL Generates the URL to invite the system-wide Discord Bot onto the merchant’s Discord server.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :product_id (String)

    Optional Product ID to redirect back to after installation

Returns:

  • (nil)


27
28
29
30
# File 'lib/solifyn/api/discord_integration_api.rb', line 27

def discord_get_install_url(opts = {})
  discord_get_install_url_with_http_info(opts)
  nil
end

#discord_get_install_url_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Get Discord Bot Installation URL Generates the URL to invite the system-wide Discord Bot onto the merchant&#39;s Discord server.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :product_id (String)

    Optional Product ID to redirect back to after installation

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/solifyn/api/discord_integration_api.rb', line 37

def discord_get_install_url_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DiscordIntegrationApi.discord_get_install_url ...'
  end
  # resource path
  local_var_path = '/v1/discord/install'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'productId'] = opts[:'product_id'] if !opts[:'product_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"DiscordIntegrationApi.discord_get_install_url",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DiscordIntegrationApi#discord_get_install_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#discord_list_roles(opts = {}) ⇒ Array<DiscordRolesResponseDto>

List Guild Discord Roles Retrieves all roles available in the connected merchant’s Discord server/guild.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



84
85
86
87
# File 'lib/solifyn/api/discord_integration_api.rb', line 84

def discord_list_roles(opts = {})
  data, _status_code, _headers = discord_list_roles_with_http_info(opts)
  data
end

#discord_list_roles_with_http_info(opts = {}) ⇒ Array<(Array<DiscordRolesResponseDto>, Integer, Hash)>

List Guild Discord Roles Retrieves all roles available in the connected merchant&#39;s Discord server/guild.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<DiscordRolesResponseDto>, Integer, Hash)>)

    Array<DiscordRolesResponseDto> data, response status code and response headers



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/solifyn/api/discord_integration_api.rb', line 93

def discord_list_roles_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DiscordIntegrationApi.discord_list_roles ...'
  end
  # resource path
  local_var_path = '/v1/discord/roles'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<DiscordRolesResponseDto>'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"DiscordIntegrationApi.discord_list_roles",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DiscordIntegrationApi#discord_list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end