Class: Solifyn::Dispute
- Inherits:
-
Object
- Object
- Solifyn::Dispute
- Defined in:
- lib/solifyn/models/dispute.rb
Instance Attribute Summary collapse
-
#access_activity_log ⇒ Object
Log of access activity.
-
#amount ⇒ Object
The dispute amount.
-
#billing_address ⇒ Object
Customer billing address details.
-
#business_id ⇒ Object
The associated business ID.
-
#created_at ⇒ Object
Timestamp when the dispute was created.
-
#currency ⇒ Object
The currency code.
-
#customer_email ⇒ Object
Customer email address.
-
#customer_name ⇒ Object
Customer name.
-
#editable ⇒ Object
Whether the evidence is still editable.
-
#evidence ⇒ Object
Evidence attachments associated with the dispute.
-
#id ⇒ Object
The dispute ID.
-
#needs_response_by ⇒ Object
Timestamp by when evidence must be submitted.
-
#notes ⇒ Object
Additional notes.
-
#payment_id ⇒ Object
The associated payment ID.
-
#product_description ⇒ Object
Product or service description.
-
#reason ⇒ Object
The reason for the dispute.
-
#service_date ⇒ Object
Service or purchase date.
-
#status ⇒ Object
The status of the dispute.
-
#updated_at ⇒ Object
Timestamp when the dispute was last updated.
-
#visa_rdr ⇒ Object
Whether Visa RDR was applied.
-
#whop_id ⇒ Object
The Whop Dispute ID.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Dispute
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Dispute
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/solifyn/models/dispute.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::Dispute` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::Dispute`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'whop_id') self.whop_id = attributes[:'whop_id'] else self.whop_id = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end if attributes.key?(:'editable') self.editable = attributes[:'editable'] else self.editable = nil end if attributes.key?(:'needs_response_by') self.needs_response_by = attributes[:'needs_response_by'] end if attributes.key?(:'visa_rdr') self.visa_rdr = attributes[:'visa_rdr'] else self.visa_rdr = nil end if attributes.key?(:'billing_address') self.billing_address = attributes[:'billing_address'] end if attributes.key?(:'customer_name') self.customer_name = attributes[:'customer_name'] end if attributes.key?(:'customer_email') self.customer_email = attributes[:'customer_email'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'product_description') self.product_description = attributes[:'product_description'] end if attributes.key?(:'service_date') self.service_date = attributes[:'service_date'] end if attributes.key?(:'access_activity_log') self.access_activity_log = attributes[:'access_activity_log'] end if attributes.key?(:'evidence') self.evidence = attributes[:'evidence'] end if attributes.key?(:'payment_id') self.payment_id = attributes[:'payment_id'] else self.payment_id = nil end if attributes.key?(:'business_id') self.business_id = attributes[:'business_id'] else self.business_id = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#access_activity_log ⇒ Object
Log of access activity
64 65 66 |
# File 'lib/solifyn/models/dispute.rb', line 64 def access_activity_log @access_activity_log end |
#amount ⇒ Object
The dispute amount
25 26 27 |
# File 'lib/solifyn/models/dispute.rb', line 25 def amount @amount end |
#billing_address ⇒ Object
Customer billing address details
46 47 48 |
# File 'lib/solifyn/models/dispute.rb', line 46 def billing_address @billing_address end |
#business_id ⇒ Object
The associated business ID
73 74 75 |
# File 'lib/solifyn/models/dispute.rb', line 73 def business_id @business_id end |
#created_at ⇒ Object
Timestamp when the dispute was created
76 77 78 |
# File 'lib/solifyn/models/dispute.rb', line 76 def created_at @created_at end |
#currency ⇒ Object
The currency code
28 29 30 |
# File 'lib/solifyn/models/dispute.rb', line 28 def currency @currency end |
#customer_email ⇒ Object
Customer email address
52 53 54 |
# File 'lib/solifyn/models/dispute.rb', line 52 def customer_email @customer_email end |
#customer_name ⇒ Object
Customer name
49 50 51 |
# File 'lib/solifyn/models/dispute.rb', line 49 def customer_name @customer_name end |
#editable ⇒ Object
Whether the evidence is still editable
37 38 39 |
# File 'lib/solifyn/models/dispute.rb', line 37 def editable @editable end |
#evidence ⇒ Object
Evidence attachments associated with the dispute
67 68 69 |
# File 'lib/solifyn/models/dispute.rb', line 67 def evidence @evidence end |
#id ⇒ Object
The dispute ID
19 20 21 |
# File 'lib/solifyn/models/dispute.rb', line 19 def id @id end |
#needs_response_by ⇒ Object
Timestamp by when evidence must be submitted
40 41 42 |
# File 'lib/solifyn/models/dispute.rb', line 40 def needs_response_by @needs_response_by end |
#notes ⇒ Object
Additional notes
55 56 57 |
# File 'lib/solifyn/models/dispute.rb', line 55 def notes @notes end |
#payment_id ⇒ Object
The associated payment ID
70 71 72 |
# File 'lib/solifyn/models/dispute.rb', line 70 def payment_id @payment_id end |
#product_description ⇒ Object
Product or service description
58 59 60 |
# File 'lib/solifyn/models/dispute.rb', line 58 def product_description @product_description end |
#reason ⇒ Object
The reason for the dispute
34 35 36 |
# File 'lib/solifyn/models/dispute.rb', line 34 def reason @reason end |
#service_date ⇒ Object
Service or purchase date
61 62 63 |
# File 'lib/solifyn/models/dispute.rb', line 61 def service_date @service_date end |
#status ⇒ Object
The status of the dispute
31 32 33 |
# File 'lib/solifyn/models/dispute.rb', line 31 def status @status end |
#updated_at ⇒ Object
Timestamp when the dispute was last updated
79 80 81 |
# File 'lib/solifyn/models/dispute.rb', line 79 def updated_at @updated_at end |
#visa_rdr ⇒ Object
Whether Visa RDR was applied
43 44 45 |
# File 'lib/solifyn/models/dispute.rb', line 43 def visa_rdr @visa_rdr end |
#whop_id ⇒ Object
The Whop Dispute ID
22 23 24 |
# File 'lib/solifyn/models/dispute.rb', line 22 def whop_id @whop_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/solifyn/models/dispute.rb', line 405 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/solifyn/models/dispute.rb', line 109 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/solifyn/models/dispute.rb', line 82 def self.attribute_map { :'id' => :'id', :'whop_id' => :'whopId', :'amount' => :'amount', :'currency' => :'currency', :'status' => :'status', :'reason' => :'reason', :'editable' => :'editable', :'needs_response_by' => :'needsResponseBy', :'visa_rdr' => :'visaRdr', :'billing_address' => :'billingAddress', :'customer_name' => :'customerName', :'customer_email' => :'customerEmail', :'notes' => :'notes', :'product_description' => :'productDescription', :'service_date' => :'serviceDate', :'access_activity_log' => :'accessActivityLog', :'evidence' => :'evidence', :'payment_id' => :'paymentId', :'business_id' => :'businessId', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/solifyn/models/dispute.rb', line 381 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
141 142 143 144 |
# File 'lib/solifyn/models/dispute.rb', line 141 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/solifyn/models/dispute.rb', line 114 def self.openapi_types { :'id' => :'String', :'whop_id' => :'String', :'amount' => :'Float', :'currency' => :'String', :'status' => :'String', :'reason' => :'String', :'editable' => :'Boolean', :'needs_response_by' => :'Time', :'visa_rdr' => :'Boolean', :'billing_address' => :'String', :'customer_name' => :'String', :'customer_email' => :'String', :'notes' => :'String', :'product_description' => :'String', :'service_date' => :'String', :'access_activity_log' => :'String', :'evidence' => :'DisputeEvidenceDto', :'payment_id' => :'String', :'business_id' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/solifyn/models/dispute.rb', line 340 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && whop_id == o.whop_id && amount == o.amount && currency == o.currency && status == o.status && reason == o.reason && editable == o.editable && needs_response_by == o.needs_response_by && visa_rdr == o.visa_rdr && billing_address == o.billing_address && customer_name == o.customer_name && customer_email == o.customer_email && notes == o.notes && product_description == o.product_description && service_date == o.service_date && access_activity_log == o.access_activity_log && evidence == o.evidence && payment_id == o.payment_id && business_id == o.business_id && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/solifyn/models/dispute.rb', line 476 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
368 369 370 |
# File 'lib/solifyn/models/dispute.rb', line 368 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
374 375 376 |
# File 'lib/solifyn/models/dispute.rb', line 374 def hash [id, whop_id, amount, currency, status, reason, editable, needs_response_by, visa_rdr, billing_address, customer_name, customer_email, notes, product_description, service_date, access_activity_log, evidence, payment_id, business_id, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/solifyn/models/dispute.rb', line 270 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @whop_id.nil? invalid_properties.push('invalid value for "whop_id", whop_id cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @editable.nil? invalid_properties.push('invalid value for "editable", editable cannot be nil.') end if @visa_rdr.nil? invalid_properties.push('invalid value for "visa_rdr", visa_rdr cannot be nil.') end if @payment_id.nil? invalid_properties.push('invalid value for "payment_id", payment_id cannot be nil.') end if @business_id.nil? invalid_properties.push('invalid value for "business_id", business_id cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
452 453 454 |
# File 'lib/solifyn/models/dispute.rb', line 452 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/solifyn/models/dispute.rb', line 458 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
446 447 448 |
# File 'lib/solifyn/models/dispute.rb', line 446 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/solifyn/models/dispute.rb', line 322 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @whop_id.nil? return false if @amount.nil? return false if @currency.nil? return false if @status.nil? return false if @editable.nil? return false if @visa_rdr.nil? return false if @payment_id.nil? return false if @business_id.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |