Class: Solifyn::DisputesApi
- Inherits:
-
Object
- Object
- Solifyn::DisputesApi
- Defined in:
- lib/solifyn/api/disputes_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#disputes_generate_report(opts = {}) ⇒ nil
Generate Dispute CSV Report Generates a downloadable CSV report of disputes matching the filters.
-
#disputes_generate_report_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Generate Dispute CSV Report Generates a downloadable CSV report of disputes matching the filters.
-
#disputes_get(id, opts = {}) ⇒ Dispute
Retrieve Dispute Retrieve details of a specific dispute by ID.
-
#disputes_get_with_http_info(id, opts = {}) ⇒ Array<(Dispute, Integer, Hash)>
Retrieve Dispute Retrieve details of a specific dispute by ID.
-
#disputes_list(opts = {}) ⇒ DisputeList
List Disputes Retrieve disputes associated with the active business.
-
#disputes_list_with_http_info(opts = {}) ⇒ Array<(DisputeList, Integer, Hash)>
List Disputes Retrieve disputes associated with the active business.
-
#disputes_submit_evidence(id, opts = {}) ⇒ Dispute
Submit Dispute Evidence Finalize and submit the uploaded evidence for review.
-
#disputes_submit_evidence_with_http_info(id, opts = {}) ⇒ Array<(Dispute, Integer, Hash)>
Submit Dispute Evidence Finalize and submit the uploaded evidence for review.
-
#disputes_update_evidence(id, dispute_evidence_update, opts = {}) ⇒ Dispute
Update Dispute Evidence Upload and update evidence attachments for a dispute.
-
#disputes_update_evidence_with_http_info(id, dispute_evidence_update, opts = {}) ⇒ Array<(Dispute, Integer, Hash)>
Update Dispute Evidence Upload and update evidence attachments for a dispute.
-
#disputes_upload_evidence_file(file, opts = {}) ⇒ DisputeFileUpload
Upload Evidence File Upload a support file (image, PDF, video) to use as dispute evidence.
-
#disputes_upload_evidence_file_with_http_info(file, opts = {}) ⇒ Array<(DisputeFileUpload, Integer, Hash)>
Upload Evidence File Upload a support file (image, PDF, video) to use as dispute evidence.
-
#initialize(api_client = ApiClient.default) ⇒ DisputesApi
constructor
A new instance of DisputesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DisputesApi
Returns a new instance of DisputesApi.
19 20 21 |
# File 'lib/solifyn/api/disputes_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/disputes_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#disputes_generate_report(opts = {}) ⇒ nil
Generate Dispute CSV Report Generates a downloadable CSV report of disputes matching the filters.
29 30 31 32 |
# File 'lib/solifyn/api/disputes_api.rb', line 29 def disputes_generate_report(opts = {}) disputes_generate_report_with_http_info(opts) nil end |
#disputes_generate_report_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Generate Dispute CSV Report Generates a downloadable CSV report of disputes matching the filters.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/solifyn/api/disputes_api.rb', line 41 def disputes_generate_report_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DisputesApi.disputes_generate_report ...' end # resource path local_var_path = '/v1/transactions/disputes/report' # query parameters query_params = opts[:query_params] || {} query_params[:'createdAtGte'] = opts[:'created_at_gte'] if !opts[:'created_at_gte'].nil? query_params[:'createdAtLte'] = opts[:'created_at_lte'] if !opts[:'created_at_lte'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DisputesApi.disputes_generate_report", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DisputesApi#disputes_generate_report\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#disputes_get(id, opts = {}) ⇒ Dispute
Retrieve Dispute Retrieve details of a specific dispute by ID.
91 92 93 94 |
# File 'lib/solifyn/api/disputes_api.rb', line 91 def disputes_get(id, opts = {}) data, _status_code, _headers = disputes_get_with_http_info(id, opts) data end |
#disputes_get_with_http_info(id, opts = {}) ⇒ Array<(Dispute, Integer, Hash)>
Retrieve Dispute Retrieve details of a specific dispute by ID.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/solifyn/api/disputes_api.rb', line 101 def disputes_get_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DisputesApi.disputes_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DisputesApi.disputes_get" end # resource path local_var_path = '/v1/transactions/disputes/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Dispute' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DisputesApi.disputes_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DisputesApi#disputes_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#disputes_list(opts = {}) ⇒ DisputeList
List Disputes Retrieve disputes associated with the active business.
157 158 159 160 |
# File 'lib/solifyn/api/disputes_api.rb', line 157 def disputes_list(opts = {}) data, _status_code, _headers = disputes_list_with_http_info(opts) data end |
#disputes_list_with_http_info(opts = {}) ⇒ Array<(DisputeList, Integer, Hash)>
List Disputes Retrieve disputes associated with the active business.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/solifyn/api/disputes_api.rb', line 170 def disputes_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DisputesApi.disputes_list ...' end # resource path local_var_path = '/v1/transactions/disputes' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DisputeList' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DisputesApi.disputes_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DisputesApi#disputes_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#disputes_submit_evidence(id, opts = {}) ⇒ Dispute
Submit Dispute Evidence Finalize and submit the uploaded evidence for review.
223 224 225 226 |
# File 'lib/solifyn/api/disputes_api.rb', line 223 def disputes_submit_evidence(id, opts = {}) data, _status_code, _headers = disputes_submit_evidence_with_http_info(id, opts) data end |
#disputes_submit_evidence_with_http_info(id, opts = {}) ⇒ Array<(Dispute, Integer, Hash)>
Submit Dispute Evidence Finalize and submit the uploaded evidence for review.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/solifyn/api/disputes_api.rb', line 233 def disputes_submit_evidence_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DisputesApi.disputes_submit_evidence ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DisputesApi.disputes_submit_evidence" end # resource path local_var_path = '/v1/transactions/disputes/{id}/submit'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Dispute' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DisputesApi.disputes_submit_evidence", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DisputesApi#disputes_submit_evidence\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#disputes_update_evidence(id, dispute_evidence_update, opts = {}) ⇒ Dispute
Update Dispute Evidence Upload and update evidence attachments for a dispute.
287 288 289 290 |
# File 'lib/solifyn/api/disputes_api.rb', line 287 def disputes_update_evidence(id, dispute_evidence_update, opts = {}) data, _status_code, _headers = disputes_update_evidence_with_http_info(id, dispute_evidence_update, opts) data end |
#disputes_update_evidence_with_http_info(id, dispute_evidence_update, opts = {}) ⇒ Array<(Dispute, Integer, Hash)>
Update Dispute Evidence Upload and update evidence attachments for a dispute.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/solifyn/api/disputes_api.rb', line 298 def disputes_update_evidence_with_http_info(id, dispute_evidence_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DisputesApi.disputes_update_evidence ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling DisputesApi.disputes_update_evidence" end # verify the required parameter 'dispute_evidence_update' is set if @api_client.config.client_side_validation && dispute_evidence_update.nil? fail ArgumentError, "Missing the required parameter 'dispute_evidence_update' when calling DisputesApi.disputes_update_evidence" end # resource path local_var_path = '/v1/transactions/disputes/{id}/evidence'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(dispute_evidence_update) # return_type return_type = opts[:debug_return_type] || 'Dispute' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DisputesApi.disputes_update_evidence", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DisputesApi#disputes_update_evidence\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#disputes_upload_evidence_file(file, opts = {}) ⇒ DisputeFileUpload
Upload Evidence File Upload a support file (image, PDF, video) to use as dispute evidence.
360 361 362 363 |
# File 'lib/solifyn/api/disputes_api.rb', line 360 def disputes_upload_evidence_file(file, opts = {}) data, _status_code, _headers = disputes_upload_evidence_file_with_http_info(file, opts) data end |
#disputes_upload_evidence_file_with_http_info(file, opts = {}) ⇒ Array<(DisputeFileUpload, Integer, Hash)>
Upload Evidence File Upload a support file (image, PDF, video) to use as dispute evidence.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/solifyn/api/disputes_api.rb', line 370 def disputes_upload_evidence_file_with_http_info(file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DisputesApi.disputes_upload_evidence_file ...' end # verify the required parameter 'file' is set if @api_client.config.client_side_validation && file.nil? fail ArgumentError, "Missing the required parameter 'file' when calling DisputesApi.disputes_upload_evidence_file" end # resource path local_var_path = '/v1/transactions/disputes/upload' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['file'] = file # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DisputeFileUpload' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DisputesApi.disputes_upload_evidence_file", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DisputesApi#disputes_upload_evidence_file\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |