Class: Solifyn::EntitlementGrantsApi
- Inherits:
-
Object
- Object
- Solifyn::EntitlementGrantsApi
- Defined in:
- lib/solifyn/api/entitlement_grants_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#entitlement_grants_get(id, opts = {}) ⇒ EntitlementGrantResponseDto
Retrieve Entitlement Grant Retrieve details of a specific entitlement grant.
-
#entitlement_grants_get_with_http_info(id, opts = {}) ⇒ Array<(EntitlementGrantResponseDto, Integer, Hash)>
Retrieve Entitlement Grant Retrieve details of a specific entitlement grant.
-
#entitlement_grants_list(opts = {}) ⇒ Array<EntitlementGrantResponseDto>
List Entitlement Grants Retrieve all GitHub repository entitlement grants for the active business.
-
#entitlement_grants_list_with_http_info(opts = {}) ⇒ Array<(Array<EntitlementGrantResponseDto>, Integer, Hash)>
List Entitlement Grants Retrieve all GitHub repository entitlement grants for the active business.
-
#entitlement_grants_retry(id, opts = {}) ⇒ EntitlementGrantResponseDto
Retry Entitlement Grant Delivery Attempts to re-invite the collaborator if GitHub username is already connected, or resets the OAuth URL redirect.
-
#entitlement_grants_retry_with_http_info(id, opts = {}) ⇒ Array<(EntitlementGrantResponseDto, Integer, Hash)>
Retry Entitlement Grant Delivery Attempts to re-invite the collaborator if GitHub username is already connected, or resets the OAuth URL redirect.
-
#entitlement_grants_revoke(id, opts = {}) ⇒ EntitlementGrantResponseDto
Manually Revoke Entitlement Grant Manually remove the customer collaborator access from the repository and revoke the grant.
-
#entitlement_grants_revoke_with_http_info(id, opts = {}) ⇒ Array<(EntitlementGrantResponseDto, Integer, Hash)>
Manually Revoke Entitlement Grant Manually remove the customer collaborator access from the repository and revoke the grant.
-
#initialize(api_client = ApiClient.default) ⇒ EntitlementGrantsApi
constructor
A new instance of EntitlementGrantsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EntitlementGrantsApi
Returns a new instance of EntitlementGrantsApi.
19 20 21 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#entitlement_grants_get(id, opts = {}) ⇒ EntitlementGrantResponseDto
Retrieve Entitlement Grant Retrieve details of a specific entitlement grant.
27 28 29 30 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 27 def entitlement_grants_get(id, opts = {}) data, _status_code, _headers = entitlement_grants_get_with_http_info(id, opts) data end |
#entitlement_grants_get_with_http_info(id, opts = {}) ⇒ Array<(EntitlementGrantResponseDto, Integer, Hash)>
Retrieve Entitlement Grant Retrieve details of a specific entitlement grant.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 37 def entitlement_grants_get_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementGrantsApi.entitlement_grants_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EntitlementGrantsApi.entitlement_grants_get" end # resource path local_var_path = '/v1/entitlement-grants/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EntitlementGrantResponseDto' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EntitlementGrantsApi.entitlement_grants_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementGrantsApi#entitlement_grants_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#entitlement_grants_list(opts = {}) ⇒ Array<EntitlementGrantResponseDto>
List Entitlement Grants Retrieve all GitHub repository entitlement grants for the active business.
90 91 92 93 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 90 def entitlement_grants_list(opts = {}) data, _status_code, _headers = entitlement_grants_list_with_http_info(opts) data end |
#entitlement_grants_list_with_http_info(opts = {}) ⇒ Array<(Array<EntitlementGrantResponseDto>, Integer, Hash)>
List Entitlement Grants Retrieve all GitHub repository entitlement grants for the active business.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 100 def entitlement_grants_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementGrantsApi.entitlement_grants_list ...' end # resource path local_var_path = '/v1/entitlement-grants' # query parameters query_params = opts[:query_params] || {} query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<EntitlementGrantResponseDto>' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EntitlementGrantsApi.entitlement_grants_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementGrantsApi#entitlement_grants_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#entitlement_grants_retry(id, opts = {}) ⇒ EntitlementGrantResponseDto
Retry Entitlement Grant Delivery Attempts to re-invite the collaborator if GitHub username is already connected, or resets the OAuth URL redirect.
150 151 152 153 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 150 def entitlement_grants_retry(id, opts = {}) data, _status_code, _headers = entitlement_grants_retry_with_http_info(id, opts) data end |
#entitlement_grants_retry_with_http_info(id, opts = {}) ⇒ Array<(EntitlementGrantResponseDto, Integer, Hash)>
Retry Entitlement Grant Delivery Attempts to re-invite the collaborator if GitHub username is already connected, or resets the OAuth URL redirect.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 160 def entitlement_grants_retry_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementGrantsApi.entitlement_grants_retry ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EntitlementGrantsApi.entitlement_grants_retry" end # resource path local_var_path = '/v1/entitlement-grants/{id}/retry'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EntitlementGrantResponseDto' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EntitlementGrantsApi.entitlement_grants_retry", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementGrantsApi#entitlement_grants_retry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#entitlement_grants_revoke(id, opts = {}) ⇒ EntitlementGrantResponseDto
Manually Revoke Entitlement Grant Manually remove the customer collaborator access from the repository and revoke the grant.
213 214 215 216 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 213 def entitlement_grants_revoke(id, opts = {}) data, _status_code, _headers = entitlement_grants_revoke_with_http_info(id, opts) data end |
#entitlement_grants_revoke_with_http_info(id, opts = {}) ⇒ Array<(EntitlementGrantResponseDto, Integer, Hash)>
Manually Revoke Entitlement Grant Manually remove the customer collaborator access from the repository and revoke the grant.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/solifyn/api/entitlement_grants_api.rb', line 223 def entitlement_grants_revoke_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementGrantsApi.entitlement_grants_revoke ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EntitlementGrantsApi.entitlement_grants_revoke" end # resource path local_var_path = '/v1/entitlement-grants/{id}/revoke'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EntitlementGrantResponseDto' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"EntitlementGrantsApi.entitlement_grants_revoke", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementGrantsApi#entitlement_grants_revoke\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |