Class: Solifyn::FramerIntegrationApi
- Inherits:
-
Object
- Object
- Solifyn::FramerIntegrationApi
- Defined in:
- lib/solifyn/api/framer_integration_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#framer_create_template(create_framer_template_dto, opts = {}) ⇒ FramerTemplateResponseDto
Create Framer Template Registers a new Framer template with its public remix link for the active business.
-
#framer_create_template_with_http_info(create_framer_template_dto, opts = {}) ⇒ Array<(FramerTemplateResponseDto, Integer, Hash)>
Create Framer Template Registers a new Framer template with its public remix link for the active business.
-
#framer_delete_template(id, opts = {}) ⇒ nil
Delete Framer Template Deletes a registered Framer template for the active business.
-
#framer_delete_template_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Framer Template Deletes a registered Framer template for the active business.
-
#framer_get_template(id, opts = {}) ⇒ FramerTemplateResponseDto
Retrieve Framer Template Retrieves details of a specific registered Framer template.
-
#framer_get_template_with_http_info(id, opts = {}) ⇒ Array<(FramerTemplateResponseDto, Integer, Hash)>
Retrieve Framer Template Retrieves details of a specific registered Framer template.
-
#framer_list_templates(opts = {}) ⇒ Array<FramerTemplateResponseDto>
List Framer Templates Retrieves all registered Framer templates for the active business.
-
#framer_list_templates_with_http_info(opts = {}) ⇒ Array<(Array<FramerTemplateResponseDto>, Integer, Hash)>
List Framer Templates Retrieves all registered Framer templates for the active business.
-
#framer_update_template(id, update_framer_template_dto, opts = {}) ⇒ FramerTemplateResponseDto
Update Framer Template Updates a registered Framer template for the active business.
-
#framer_update_template_with_http_info(id, update_framer_template_dto, opts = {}) ⇒ Array<(FramerTemplateResponseDto, Integer, Hash)>
Update Framer Template Updates a registered Framer template for the active business.
-
#initialize(api_client = ApiClient.default) ⇒ FramerIntegrationApi
constructor
A new instance of FramerIntegrationApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ FramerIntegrationApi
Returns a new instance of FramerIntegrationApi.
19 20 21 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#framer_create_template(create_framer_template_dto, opts = {}) ⇒ FramerTemplateResponseDto
Create Framer Template Registers a new Framer template with its public remix link for the active business.
27 28 29 30 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 27 def framer_create_template(create_framer_template_dto, opts = {}) data, _status_code, _headers = framer_create_template_with_http_info(create_framer_template_dto, opts) data end |
#framer_create_template_with_http_info(create_framer_template_dto, opts = {}) ⇒ Array<(FramerTemplateResponseDto, Integer, Hash)>
Create Framer Template Registers a new Framer template with its public remix link for the active business.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 37 def framer_create_template_with_http_info(create_framer_template_dto, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FramerIntegrationApi.framer_create_template ...' end # verify the required parameter 'create_framer_template_dto' is set if @api_client.config.client_side_validation && create_framer_template_dto.nil? fail ArgumentError, "Missing the required parameter 'create_framer_template_dto' when calling FramerIntegrationApi.framer_create_template" end # resource path local_var_path = '/v1/framer/templates' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_framer_template_dto) # return_type return_type = opts[:debug_return_type] || 'FramerTemplateResponseDto' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"FramerIntegrationApi.framer_create_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FramerIntegrationApi#framer_create_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#framer_delete_template(id, opts = {}) ⇒ nil
Delete Framer Template Deletes a registered Framer template for the active business.
95 96 97 98 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 95 def framer_delete_template(id, opts = {}) framer_delete_template_with_http_info(id, opts) nil end |
#framer_delete_template_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Framer Template Deletes a registered Framer template for the active business.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 105 def framer_delete_template_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FramerIntegrationApi.framer_delete_template ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FramerIntegrationApi.framer_delete_template" end # resource path local_var_path = '/v1/framer/templates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"FramerIntegrationApi.framer_delete_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FramerIntegrationApi#framer_delete_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#framer_get_template(id, opts = {}) ⇒ FramerTemplateResponseDto
Retrieve Framer Template Retrieves details of a specific registered Framer template.
156 157 158 159 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 156 def framer_get_template(id, opts = {}) data, _status_code, _headers = framer_get_template_with_http_info(id, opts) data end |
#framer_get_template_with_http_info(id, opts = {}) ⇒ Array<(FramerTemplateResponseDto, Integer, Hash)>
Retrieve Framer Template Retrieves details of a specific registered Framer template.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 166 def framer_get_template_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FramerIntegrationApi.framer_get_template ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FramerIntegrationApi.framer_get_template" end # resource path local_var_path = '/v1/framer/templates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'FramerTemplateResponseDto' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"FramerIntegrationApi.framer_get_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FramerIntegrationApi#framer_get_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#framer_list_templates(opts = {}) ⇒ Array<FramerTemplateResponseDto>
List Framer Templates Retrieves all registered Framer templates for the active business.
218 219 220 221 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 218 def framer_list_templates(opts = {}) data, _status_code, _headers = framer_list_templates_with_http_info(opts) data end |
#framer_list_templates_with_http_info(opts = {}) ⇒ Array<(Array<FramerTemplateResponseDto>, Integer, Hash)>
List Framer Templates Retrieves all registered Framer templates for the active business.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 227 def framer_list_templates_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FramerIntegrationApi.framer_list_templates ...' end # resource path local_var_path = '/v1/framer/templates' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<FramerTemplateResponseDto>' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"FramerIntegrationApi.framer_list_templates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FramerIntegrationApi#framer_list_templates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#framer_update_template(id, update_framer_template_dto, opts = {}) ⇒ FramerTemplateResponseDto
Update Framer Template Updates a registered Framer template for the active business.
277 278 279 280 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 277 def framer_update_template(id, update_framer_template_dto, opts = {}) data, _status_code, _headers = framer_update_template_with_http_info(id, update_framer_template_dto, opts) data end |
#framer_update_template_with_http_info(id, update_framer_template_dto, opts = {}) ⇒ Array<(FramerTemplateResponseDto, Integer, Hash)>
Update Framer Template Updates a registered Framer template for the active business.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/solifyn/api/framer_integration_api.rb', line 288 def framer_update_template_with_http_info(id, update_framer_template_dto, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FramerIntegrationApi.framer_update_template ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FramerIntegrationApi.framer_update_template" end # verify the required parameter 'update_framer_template_dto' is set if @api_client.config.client_side_validation && update_framer_template_dto.nil? fail ArgumentError, "Missing the required parameter 'update_framer_template_dto' when calling FramerIntegrationApi.framer_update_template" end # resource path local_var_path = '/v1/framer/templates/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_framer_template_dto) # return_type return_type = opts[:debug_return_type] || 'FramerTemplateResponseDto' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"FramerIntegrationApi.framer_update_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FramerIntegrationApi#framer_update_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |