Class: Solifyn::MeterResponseDto
- Inherits:
-
Object
- Object
- Solifyn::MeterResponseDto
- Defined in:
- lib/solifyn/models/meter_response_dto.rb
Overview
Represents a usage meter configured for event-based billing, including the tracked event name, aggregation strategy, optional filters, and archive status.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aggregation_key ⇒ Object
Metadata key used for aggregation.
-
#aggregation_type ⇒ Object
Aggregation strategy for usage events.
-
#archived ⇒ Object
Whether the meter is archived.
-
#business_id ⇒ Object
The business ID that owns this meter.
-
#created_at ⇒ Object
Creation timestamp.
-
#description ⇒ Object
Meter description.
-
#event_name ⇒ Object
The event name tracked by this meter.
-
#filters ⇒ Object
Optional filter definition for advanced matching.
-
#id ⇒ Object
The unique meter ID.
-
#name ⇒ Object
Meter display name.
-
#unit ⇒ Object
Measurement unit label.
-
#updated_at ⇒ Object
Last update timestamp.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MeterResponseDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MeterResponseDto
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::MeterResponseDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::MeterResponseDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'business_id') self.business_id = attributes[:'business_id'] else self.business_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'event_name') self.event_name = attributes[:'event_name'] else self.event_name = nil end if attributes.key?(:'aggregation_type') self.aggregation_type = attributes[:'aggregation_type'] else self.aggregation_type = nil end if attributes.key?(:'aggregation_key') self.aggregation_key = attributes[:'aggregation_key'] end if attributes.key?(:'unit') self.unit = attributes[:'unit'] end if attributes.key?(:'filters') if (value = attributes[:'filters']).is_a?(Hash) self.filters = value end end if attributes.key?(:'archived') self.archived = attributes[:'archived'] else self.archived = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#aggregation_key ⇒ Object
Metadata key used for aggregation.
38 39 40 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 38 def aggregation_key @aggregation_key end |
#aggregation_type ⇒ Object
Aggregation strategy for usage events.
35 36 37 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 35 def aggregation_type @aggregation_type end |
#archived ⇒ Object
Whether the meter is archived.
47 48 49 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 47 def archived @archived end |
#business_id ⇒ Object
The business ID that owns this meter.
23 24 25 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 23 def business_id @business_id end |
#created_at ⇒ Object
Creation timestamp.
50 51 52 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 50 def created_at @created_at end |
#description ⇒ Object
Meter description.
29 30 31 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 29 def description @description end |
#event_name ⇒ Object
The event name tracked by this meter.
32 33 34 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 32 def event_name @event_name end |
#filters ⇒ Object
Optional filter definition for advanced matching.
44 45 46 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 44 def filters @filters end |
#id ⇒ Object
The unique meter ID.
20 21 22 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 20 def id @id end |
#name ⇒ Object
Meter display name.
26 27 28 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 26 def name @name end |
#unit ⇒ Object
Measurement unit label.
41 42 43 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 41 def unit @unit end |
#updated_at ⇒ Object
Last update timestamp.
53 54 55 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 53 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 331 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 96 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 78 def self.attribute_map { :'id' => :'id', :'business_id' => :'businessId', :'name' => :'name', :'description' => :'description', :'event_name' => :'eventName', :'aggregation_type' => :'aggregationType', :'aggregation_key' => :'aggregationKey', :'unit' => :'unit', :'filters' => :'filters', :'archived' => :'archived', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 307 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
119 120 121 122 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 119 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 101 def self.openapi_types { :'id' => :'String', :'business_id' => :'String', :'name' => :'String', :'description' => :'Object', :'event_name' => :'String', :'aggregation_type' => :'String', :'aggregation_key' => :'Object', :'unit' => :'Object', :'filters' => :'Hash<String, Object>', :'archived' => :'Boolean', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 275 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && business_id == o.business_id && name == o.name && description == o.description && event_name == o.event_name && aggregation_type == o.aggregation_type && aggregation_key == o.aggregation_key && unit == o.unit && filters == o.filters && archived == o.archived && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 402 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
294 295 296 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 294 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
300 301 302 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 300 def hash [id, business_id, name, description, event_name, aggregation_type, aggregation_key, unit, filters, archived, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 208 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @business_id.nil? invalid_properties.push('invalid value for "business_id", business_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @event_name.nil? invalid_properties.push('invalid value for "event_name", event_name cannot be nil.') end if @aggregation_type.nil? invalid_properties.push('invalid value for "aggregation_type", aggregation_type cannot be nil.') end if @archived.nil? invalid_properties.push('invalid value for "archived", archived cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
378 379 380 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 378 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 384 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
372 373 374 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 372 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/solifyn/models/meter_response_dto.rb', line 248 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @business_id.nil? return false if @name.nil? return false if @event_name.nil? return false if @aggregation_type.nil? aggregation_type_validator = EnumAttributeValidator.new('String', ["COUNT", "SUM", "MAX", "LAST"]) return false unless aggregation_type_validator.valid?(@aggregation_type) return false if @archived.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |