Class: Solifyn::OperationalWebhookEndpointResponseDto
- Inherits:
-
Object
- Object
- Solifyn::OperationalWebhookEndpointResponseDto
- Defined in:
- lib/solifyn/models/operational_webhook_endpoint_response_dto.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#disabled ⇒ Object
Returns the value of attribute disabled.
-
#filter_types ⇒ Object
Returns the value of attribute filter_types.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#secret ⇒ Object
The endpoint’s raw secret (only returned on POST creation).
-
#throttle_rate ⇒ Object
Returns the value of attribute throttle_rate.
-
#uid ⇒ Object
Returns the value of attribute uid.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperationalWebhookEndpointResponseDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OperationalWebhookEndpointResponseDto
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::OperationalWebhookEndpointResponseDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::OperationalWebhookEndpointResponseDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] else self.disabled = nil end if attributes.key?(:'filter_types') if (value = attributes[:'filter_types']).is_a?(Array) self.filter_types = value end else self.filter_types = nil end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'throttle_rate') self.throttle_rate = attributes[:'throttle_rate'] else self.throttle_rate = nil end if attributes.key?(:'uid') self.uid = attributes[:'uid'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 34 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 22 def description @description end |
#disabled ⇒ Object
Returns the value of attribute disabled.
24 25 26 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 24 def disabled @disabled end |
#filter_types ⇒ Object
Returns the value of attribute filter_types.
26 27 28 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 26 def filter_types @filter_types end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 18 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
28 29 30 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 28 def @metadata end |
#secret ⇒ Object
The endpoint’s raw secret (only returned on POST creation).
39 40 41 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 39 def secret @secret end |
#throttle_rate ⇒ Object
Returns the value of attribute throttle_rate.
30 31 32 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 30 def throttle_rate @throttle_rate end |
#uid ⇒ Object
Returns the value of attribute uid.
32 33 34 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 32 def uid @uid end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 36 def updated_at @updated_at end |
#url ⇒ Object
Returns the value of attribute url.
20 21 22 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 20 def url @url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 276 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 59 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 42 def self.attribute_map { :'id' => :'id', :'url' => :'url', :'description' => :'description', :'disabled' => :'disabled', :'filter_types' => :'filterTypes', :'metadata' => :'metadata', :'throttle_rate' => :'throttleRate', :'uid' => :'uid', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'secret' => :'secret' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 252 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 64 def self.openapi_types { :'id' => :'String', :'url' => :'String', :'description' => :'String', :'disabled' => :'Boolean', :'filter_types' => :'Array<String>', :'metadata' => :'Object', :'throttle_rate' => :'Float', :'uid' => :'Object', :'created_at' => :'Time', :'updated_at' => :'Time', :'secret' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && url == o.url && description == o.description && disabled == o.disabled && filter_types == o.filter_types && == o. && throttle_rate == o.throttle_rate && uid == o.uid && created_at == o.created_at && updated_at == o.updated_at && secret == o.secret end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 347 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
239 240 241 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 239 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 245 def hash [id, url, description, disabled, filter_types, , throttle_rate, uid, created_at, updated_at, secret].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @disabled.nil? invalid_properties.push('invalid value for "disabled", disabled cannot be nil.') end if @filter_types.nil? invalid_properties.push('invalid value for "filter_types", filter_types cannot be nil.') end if @throttle_rate.nil? invalid_properties.push('invalid value for "throttle_rate", throttle_rate cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
323 324 325 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 323 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 317 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/solifyn/models/operational_webhook_endpoint_response_dto.rb', line 206 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @url.nil? return false if @description.nil? return false if @disabled.nil? return false if @filter_types.nil? return false if @throttle_rate.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |