Class: Solifyn::ProductCreate
- Inherits:
-
Object
- Object
- Solifyn::ProductCreate
- Defined in:
- lib/solifyn/models/product_create.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#activation_limit ⇒ Object
Maximum concurrent activated instances allowed per license key.
-
#addons ⇒ Object
Product addons configurations.
-
#billing_period ⇒ Object
Billing period in days (for Subscription products).
-
#brand_id ⇒ Object
Brand id for the product, if not provided will default to primary brand.
-
#currency ⇒ Object
Product pricing currency.
-
#custom_fields ⇒ Object
Form field configurations to gather during checkout.
-
#description ⇒ Object
A description of the product.
-
#discord_guild_id ⇒ Object
Discord Guild (Server) ID to grant access to.
-
#discord_role_id ⇒ Object
Discord Role ID to assign to the user.
-
#discount ⇒ Object
Percentage or flat rate discount.
-
#entitlement_ids ⇒ Object
Array of independent entitlement IDs to link to this product.
-
#expiration_days ⇒ Object
Subscription expiration duration in days.
-
#framer_template_id ⇒ Object
Framer Template ID to grant access to.
-
#github_permission ⇒ Object
GitHub collaborator permission level.
-
#github_repo ⇒ Object
GitHub repository to grant access to (format: owner/repo).
-
#has_digital_delivery ⇒ Object
Whether the purchase includes downloadable files.
-
#has_discord_access ⇒ Object
Whether the purchase includes Discord server role access.
-
#has_framer_access ⇒ Object
Whether the purchase includes Framer Template access.
-
#has_github_access ⇒ Object
Whether the purchase includes GitHub repository access.
-
#has_license_key ⇒ Object
Whether to automatically issue license keys upon successful orders.
-
#image_url ⇒ Object
URL of the product cover image.
-
#is_free ⇒ Object
Whether the product is free of charge.
-
#is_listed ⇒ Object
Whether the product is publicly visible.
-
#is_tax_inclusive ⇒ Object
Whether tax is included in the base price.
-
#metadata ⇒ Object
Developer key-value metadata pairs.
-
#name ⇒ Object
Product display name.
-
#pay_what_you_want ⇒ Object
Allow pay-what-you-want pricing.
-
#price ⇒ Object
Price value.
-
#statement_descriptor ⇒ Object
Custom billing descriptor.
-
#stock ⇒ Object
Initial stock quantity limit.
-
#tax_category ⇒ Object
Tax classification.
-
#trial_period_days ⇒ Object
Trial duration in days.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProductCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ProductCreate
Initializes the object
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/solifyn/models/product_create.rb', line 225 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::ProductCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::ProductCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'price') self.price = attributes[:'price'] else self.price = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = 'USD' end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'tax_category') self.tax_category = attributes[:'tax_category'] else self.tax_category = nil end if attributes.key?(:'discount') self.discount = attributes[:'discount'] end if attributes.key?(:'has_license_key') self.has_license_key = attributes[:'has_license_key'] else self.has_license_key = false end if attributes.key?(:'has_digital_delivery') self.has_digital_delivery = attributes[:'has_digital_delivery'] else self.has_digital_delivery = false end if attributes.key?(:'has_github_access') self.has_github_access = attributes[:'has_github_access'] else self.has_github_access = false end if attributes.key?(:'github_repo') self.github_repo = attributes[:'github_repo'] end if attributes.key?(:'github_permission') self. = attributes[:'github_permission'] end if attributes.key?(:'has_discord_access') self.has_discord_access = attributes[:'has_discord_access'] else self.has_discord_access = false end if attributes.key?(:'discord_guild_id') self.discord_guild_id = attributes[:'discord_guild_id'] end if attributes.key?(:'discord_role_id') self.discord_role_id = attributes[:'discord_role_id'] end if attributes.key?(:'has_framer_access') self.has_framer_access = attributes[:'has_framer_access'] else self.has_framer_access = false end if attributes.key?(:'framer_template_id') self.framer_template_id = attributes[:'framer_template_id'] end if attributes.key?(:'is_tax_inclusive') self.is_tax_inclusive = attributes[:'is_tax_inclusive'] else self.is_tax_inclusive = false end if attributes.key?(:'activation_limit') self.activation_limit = attributes[:'activation_limit'] end if attributes.key?(:'brand_id') self.brand_id = attributes[:'brand_id'] end if attributes.key?(:'billing_period') self.billing_period = attributes[:'billing_period'] end if attributes.key?(:'trial_period_days') self.trial_period_days = attributes[:'trial_period_days'] end if attributes.key?(:'expiration_days') self.expiration_days = attributes[:'expiration_days'] end if attributes.key?(:'statement_descriptor') self.statement_descriptor = attributes[:'statement_descriptor'] end if attributes.key?(:'pay_what_you_want') self.pay_what_you_want = attributes[:'pay_what_you_want'] else self.pay_what_you_want = false end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'custom_fields') if (value = attributes[:'custom_fields']).is_a?(Array) self.custom_fields = value end end if attributes.key?(:'stock') self.stock = attributes[:'stock'] end if attributes.key?(:'is_listed') self.is_listed = attributes[:'is_listed'] else self.is_listed = true end if attributes.key?(:'is_free') self.is_free = attributes[:'is_free'] else self.is_free = false end if attributes.key?(:'addons') if (value = attributes[:'addons']).is_a?(Array) self.addons = value end end if attributes.key?(:'entitlement_ids') if (value = attributes[:'entitlement_ids']).is_a?(Array) self.entitlement_ids = value end end end |
Instance Attribute Details
#activation_limit ⇒ Object
Maximum concurrent activated instances allowed per license key.
73 74 75 |
# File 'lib/solifyn/models/product_create.rb', line 73 def activation_limit @activation_limit end |
#addons ⇒ Object
Product addons configurations.
109 110 111 |
# File 'lib/solifyn/models/product_create.rb', line 109 def addons @addons end |
#billing_period ⇒ Object
Billing period in days (for Subscription products).
79 80 81 |
# File 'lib/solifyn/models/product_create.rb', line 79 def billing_period @billing_period end |
#brand_id ⇒ Object
Brand id for the product, if not provided will default to primary brand.
76 77 78 |
# File 'lib/solifyn/models/product_create.rb', line 76 def brand_id @brand_id end |
#currency ⇒ Object
Product pricing currency.
28 29 30 |
# File 'lib/solifyn/models/product_create.rb', line 28 def currency @currency end |
#custom_fields ⇒ Object
Form field configurations to gather during checkout.
97 98 99 |
# File 'lib/solifyn/models/product_create.rb', line 97 def custom_fields @custom_fields end |
#description ⇒ Object
A description of the product.
22 23 24 |
# File 'lib/solifyn/models/product_create.rb', line 22 def description @description end |
#discord_guild_id ⇒ Object
Discord Guild (Server) ID to grant access to.
58 59 60 |
# File 'lib/solifyn/models/product_create.rb', line 58 def discord_guild_id @discord_guild_id end |
#discord_role_id ⇒ Object
Discord Role ID to assign to the user.
61 62 63 |
# File 'lib/solifyn/models/product_create.rb', line 61 def discord_role_id @discord_role_id end |
#discount ⇒ Object
Percentage or flat rate discount.
37 38 39 |
# File 'lib/solifyn/models/product_create.rb', line 37 def discount @discount end |
#entitlement_ids ⇒ Object
Array of independent entitlement IDs to link to this product.
112 113 114 |
# File 'lib/solifyn/models/product_create.rb', line 112 def entitlement_ids @entitlement_ids end |
#expiration_days ⇒ Object
Subscription expiration duration in days.
85 86 87 |
# File 'lib/solifyn/models/product_create.rb', line 85 def expiration_days @expiration_days end |
#framer_template_id ⇒ Object
Framer Template ID to grant access to.
67 68 69 |
# File 'lib/solifyn/models/product_create.rb', line 67 def framer_template_id @framer_template_id end |
#github_permission ⇒ Object
GitHub collaborator permission level.
52 53 54 |
# File 'lib/solifyn/models/product_create.rb', line 52 def @github_permission end |
#github_repo ⇒ Object
GitHub repository to grant access to (format: owner/repo).
49 50 51 |
# File 'lib/solifyn/models/product_create.rb', line 49 def github_repo @github_repo end |
#has_digital_delivery ⇒ Object
Whether the purchase includes downloadable files.
43 44 45 |
# File 'lib/solifyn/models/product_create.rb', line 43 def has_digital_delivery @has_digital_delivery end |
#has_discord_access ⇒ Object
Whether the purchase includes Discord server role access.
55 56 57 |
# File 'lib/solifyn/models/product_create.rb', line 55 def has_discord_access @has_discord_access end |
#has_framer_access ⇒ Object
Whether the purchase includes Framer Template access.
64 65 66 |
# File 'lib/solifyn/models/product_create.rb', line 64 def has_framer_access @has_framer_access end |
#has_github_access ⇒ Object
Whether the purchase includes GitHub repository access.
46 47 48 |
# File 'lib/solifyn/models/product_create.rb', line 46 def has_github_access @has_github_access end |
#has_license_key ⇒ Object
Whether to automatically issue license keys upon successful orders.
40 41 42 |
# File 'lib/solifyn/models/product_create.rb', line 40 def has_license_key @has_license_key end |
#image_url ⇒ Object
URL of the product cover image.
31 32 33 |
# File 'lib/solifyn/models/product_create.rb', line 31 def image_url @image_url end |
#is_free ⇒ Object
Whether the product is free of charge.
106 107 108 |
# File 'lib/solifyn/models/product_create.rb', line 106 def is_free @is_free end |
#is_listed ⇒ Object
Whether the product is publicly visible.
103 104 105 |
# File 'lib/solifyn/models/product_create.rb', line 103 def is_listed @is_listed end |
#is_tax_inclusive ⇒ Object
Whether tax is included in the base price.
70 71 72 |
# File 'lib/solifyn/models/product_create.rb', line 70 def is_tax_inclusive @is_tax_inclusive end |
#metadata ⇒ Object
Developer key-value metadata pairs.
94 95 96 |
# File 'lib/solifyn/models/product_create.rb', line 94 def @metadata end |
#name ⇒ Object
Product display name.
19 20 21 |
# File 'lib/solifyn/models/product_create.rb', line 19 def name @name end |
#pay_what_you_want ⇒ Object
Allow pay-what-you-want pricing.
91 92 93 |
# File 'lib/solifyn/models/product_create.rb', line 91 def pay_what_you_want @pay_what_you_want end |
#price ⇒ Object
Price value.
25 26 27 |
# File 'lib/solifyn/models/product_create.rb', line 25 def price @price end |
#statement_descriptor ⇒ Object
Custom billing descriptor.
88 89 90 |
# File 'lib/solifyn/models/product_create.rb', line 88 def statement_descriptor @statement_descriptor end |
#stock ⇒ Object
Initial stock quantity limit.
100 101 102 |
# File 'lib/solifyn/models/product_create.rb', line 100 def stock @stock end |
#tax_category ⇒ Object
Tax classification.
34 35 36 |
# File 'lib/solifyn/models/product_create.rb', line 34 def tax_category @tax_category end |
#trial_period_days ⇒ Object
Trial duration in days.
82 83 84 |
# File 'lib/solifyn/models/product_create.rb', line 82 def trial_period_days @trial_period_days end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/solifyn/models/product_create.rb', line 550 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
175 176 177 |
# File 'lib/solifyn/models/product_create.rb', line 175 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/solifyn/models/product_create.rb', line 137 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'price' => :'price', :'currency' => :'currency', :'image_url' => :'imageUrl', :'tax_category' => :'taxCategory', :'discount' => :'discount', :'has_license_key' => :'hasLicenseKey', :'has_digital_delivery' => :'hasDigitalDelivery', :'has_github_access' => :'hasGithubAccess', :'github_repo' => :'githubRepo', :'github_permission' => :'githubPermission', :'has_discord_access' => :'hasDiscordAccess', :'discord_guild_id' => :'discordGuildId', :'discord_role_id' => :'discordRoleId', :'has_framer_access' => :'hasFramerAccess', :'framer_template_id' => :'framerTemplateId', :'is_tax_inclusive' => :'isTaxInclusive', :'activation_limit' => :'activationLimit', :'brand_id' => :'brandId', :'billing_period' => :'billingPeriod', :'trial_period_days' => :'trialPeriodDays', :'expiration_days' => :'expirationDays', :'statement_descriptor' => :'statementDescriptor', :'pay_what_you_want' => :'payWhatYouWant', :'metadata' => :'metadata', :'custom_fields' => :'customFields', :'stock' => :'stock', :'is_listed' => :'isListed', :'is_free' => :'isFree', :'addons' => :'addons', :'entitlement_ids' => :'entitlementIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 |
# File 'lib/solifyn/models/product_create.rb', line 526 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
218 219 220 221 |
# File 'lib/solifyn/models/product_create.rb', line 218 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/solifyn/models/product_create.rb', line 180 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'price' => :'Float', :'currency' => :'String', :'image_url' => :'String', :'tax_category' => :'String', :'discount' => :'Float', :'has_license_key' => :'Boolean', :'has_digital_delivery' => :'Boolean', :'has_github_access' => :'Boolean', :'github_repo' => :'String', :'github_permission' => :'String', :'has_discord_access' => :'Boolean', :'discord_guild_id' => :'String', :'discord_role_id' => :'String', :'has_framer_access' => :'Boolean', :'framer_template_id' => :'String', :'is_tax_inclusive' => :'Boolean', :'activation_limit' => :'Integer', :'brand_id' => :'String', :'billing_period' => :'Integer', :'trial_period_days' => :'Integer', :'expiration_days' => :'Integer', :'statement_descriptor' => :'String', :'pay_what_you_want' => :'Boolean', :'metadata' => :'Hash<String, String>', :'custom_fields' => :'Array<ProductCreateCustomFieldsInner>', :'stock' => :'Integer', :'is_listed' => :'Boolean', :'is_free' => :'Boolean', :'addons' => :'Array<ProductCreateAddonsInner>', :'entitlement_ids' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/solifyn/models/product_create.rb', line 474 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && price == o.price && currency == o.currency && image_url == o.image_url && tax_category == o.tax_category && discount == o.discount && has_license_key == o.has_license_key && has_digital_delivery == o.has_digital_delivery && has_github_access == o.has_github_access && github_repo == o.github_repo && == o. && has_discord_access == o.has_discord_access && discord_guild_id == o.discord_guild_id && discord_role_id == o.discord_role_id && has_framer_access == o.has_framer_access && framer_template_id == o.framer_template_id && is_tax_inclusive == o.is_tax_inclusive && activation_limit == o.activation_limit && brand_id == o.brand_id && billing_period == o.billing_period && trial_period_days == o.trial_period_days && expiration_days == o.expiration_days && statement_descriptor == o.statement_descriptor && pay_what_you_want == o.pay_what_you_want && == o. && custom_fields == o.custom_fields && stock == o.stock && is_listed == o.is_listed && is_free == o.is_free && addons == o.addons && entitlement_ids == o.entitlement_ids end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
621 622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/solifyn/models/product_create.rb', line 621 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
513 514 515 |
# File 'lib/solifyn/models/product_create.rb', line 513 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
519 520 521 |
# File 'lib/solifyn/models/product_create.rb', line 519 def hash [name, description, price, currency, image_url, tax_category, discount, has_license_key, has_digital_delivery, has_github_access, github_repo, , has_discord_access, discord_guild_id, discord_role_id, has_framer_access, framer_template_id, is_tax_inclusive, activation_limit, brand_id, billing_period, trial_period_days, expiration_days, statement_descriptor, pay_what_you_want, , custom_fields, stock, is_listed, is_free, addons, entitlement_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/solifyn/models/product_create.rb', line 403 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @price.nil? invalid_properties.push('invalid value for "price", price cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @tax_category.nil? invalid_properties.push('invalid value for "tax_category", tax_category cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
597 598 599 |
# File 'lib/solifyn/models/product_create.rb', line 597 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
603 604 605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/solifyn/models/product_create.rb', line 603 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
591 592 593 |
# File 'lib/solifyn/models/product_create.rb', line 591 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/solifyn/models/product_create.rb', line 427 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @price.nil? return false if @currency.nil? currency_validator = EnumAttributeValidator.new('String', ["USD", "SGD", "INR", "AUD", "BRL", "CAD", "DKK", "EUR", "NOK", "GBP", "SEK", "CHF", "HKD", "HUF", "JPY", "MXN", "MYR", "PLN", "CZK", "NZD", "AED", "COP", "RON", "THB", "BGN", "IDR", "DOP", "PHP", "TRY", "KRW", "TWD", "VND", "PKR", "CLP", "UYU", "ARS", "ZAR", "DZD", "TND", "MAD", "KES", "KWD", "JOD", "ALL", "XCD", "AMD", "BSD", "BHD", "BOB", "BAM", "KHR", "CRC", "XOF", "EGP", "ETB", "GMD", "GHS", "GTQ", "GYD", "ILS", "JMD", "MOP", "MGA", "MUR", "MDL", "MNT", "NAD", "NGN", "MKD", "OMR", "PYG", "PEN", "QAR", "RWF", "SAR", "RSD", "LKR", "TZS", "TTD", "UZS", "RUB", "CNY"]) return false unless currency_validator.valid?(@currency) return false if @tax_category.nil? tax_category_validator = EnumAttributeValidator.new('String', ["digital_products", "saas", "physical_products", "service"]) return false unless tax_category_validator.valid?(@tax_category) = EnumAttributeValidator.new('String', ["pull", "triage", "push", "maintain", "admin"]) return false unless .valid?(@github_permission) true end |