Class: Solifyn::RefundsChargebacksApi
- Inherits:
-
Object
- Object
- Solifyn::RefundsChargebacksApi
- Defined in:
- lib/solifyn/api/refunds_chargebacks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ RefundsChargebacksApi
constructor
A new instance of RefundsChargebacksApi.
-
#refunds_create(id, order_refund_create, opts = {}) ⇒ nil
Create Refund Initiate a full or partial refund for a specific payment/order.
-
#refunds_create_with_http_info(id, order_refund_create, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create Refund Initiate a full or partial refund for a specific payment/order.
-
#refunds_get(id, opts = {}) ⇒ Refund
Retrieve Refund details Get parameters of a specific processed refund by database ID.
-
#refunds_get_with_http_info(id, opts = {}) ⇒ Array<(Refund, Integer, Hash)>
Retrieve Refund details Get parameters of a specific processed refund by database ID.
-
#refunds_list(opts = {}) ⇒ Array<Refund>
List Refunds Retrieve a list of processed refunds and chargeback transactions.
-
#refunds_list_with_http_info(opts = {}) ⇒ Array<(Array<Refund>, Integer, Hash)>
List Refunds Retrieve a list of processed refunds and chargeback transactions.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RefundsChargebacksApi
Returns a new instance of RefundsChargebacksApi.
19 20 21 |
# File 'lib/solifyn/api/refunds_chargebacks_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/refunds_chargebacks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#refunds_create(id, order_refund_create, opts = {}) ⇒ nil
Create Refund Initiate a full or partial refund for a specific payment/order.
28 29 30 31 |
# File 'lib/solifyn/api/refunds_chargebacks_api.rb', line 28 def refunds_create(id, order_refund_create, opts = {}) refunds_create_with_http_info(id, order_refund_create, opts) nil end |
#refunds_create_with_http_info(id, order_refund_create, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create Refund Initiate a full or partial refund for a specific payment/order.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/solifyn/api/refunds_chargebacks_api.rb', line 39 def refunds_create_with_http_info(id, order_refund_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RefundsChargebacksApi.refunds_create ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling RefundsChargebacksApi.refunds_create" end # verify the required parameter 'order_refund_create' is set if @api_client.config.client_side_validation && order_refund_create.nil? fail ArgumentError, "Missing the required parameter 'order_refund_create' when calling RefundsChargebacksApi.refunds_create" end # resource path local_var_path = '/v1/orders/{id}/refund'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(order_refund_create) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"RefundsChargebacksApi.refunds_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RefundsChargebacksApi#refunds_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#refunds_get(id, opts = {}) ⇒ Refund
Retrieve Refund details Get parameters of a specific processed refund by database ID.
99 100 101 102 |
# File 'lib/solifyn/api/refunds_chargebacks_api.rb', line 99 def refunds_get(id, opts = {}) data, _status_code, _headers = refunds_get_with_http_info(id, opts) data end |
#refunds_get_with_http_info(id, opts = {}) ⇒ Array<(Refund, Integer, Hash)>
Retrieve Refund details Get parameters of a specific processed refund by database ID.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/solifyn/api/refunds_chargebacks_api.rb', line 109 def refunds_get_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RefundsChargebacksApi.refunds_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling RefundsChargebacksApi.refunds_get" end # resource path local_var_path = '/v1/refunds/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Refund' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"RefundsChargebacksApi.refunds_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RefundsChargebacksApi#refunds_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#refunds_list(opts = {}) ⇒ Array<Refund>
List Refunds Retrieve a list of processed refunds and chargeback transactions.
161 162 163 164 |
# File 'lib/solifyn/api/refunds_chargebacks_api.rb', line 161 def refunds_list(opts = {}) data, _status_code, _headers = refunds_list_with_http_info(opts) data end |
#refunds_list_with_http_info(opts = {}) ⇒ Array<(Array<Refund>, Integer, Hash)>
List Refunds Retrieve a list of processed refunds and chargeback transactions.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/solifyn/api/refunds_chargebacks_api.rb', line 170 def refunds_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RefundsChargebacksApi.refunds_list ...' end # resource path local_var_path = '/v1/refunds' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Refund>' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"RefundsChargebacksApi.refunds_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RefundsChargebacksApi#refunds_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |