Class: Solifyn::UpdateCheckoutLinkDto
- Inherits:
-
Object
- Object
- Solifyn::UpdateCheckoutLinkDto
- Defined in:
- lib/solifyn/models/update_checkout_link_dto.rb
Instance Attribute Summary collapse
-
#address_line1 ⇒ Object
Prefilled customer billing address line 1.
-
#cancel_url ⇒ Object
The absolute URL to redirect to if a customer cancels the payment.
-
#city ⇒ Object
Prefilled customer billing city.
-
#collection_id ⇒ Object
Optional collection database ID to sell.
-
#country ⇒ Object
Prefilled customer billing country (2-letter ISO).
-
#customer_email ⇒ Object
Prefilled customer email for checkout inputs.
-
#customer_name ⇒ Object
Prefilled customer name for checkout inputs.
-
#postal_code ⇒ Object
Prefilled customer billing zip/postal code.
-
#product_id ⇒ Object
Product database/Whop ID to sell.
-
#quantity ⇒ Object
Override quantity for checkout session.
-
#redirect_url ⇒ Object
The absolute URL to redirect to upon successful payment completion.
-
#show_discounts ⇒ Object
Whether to display discount input form fields on checkout screen.
-
#state ⇒ Object
Prefilled customer billing state.
-
#title ⇒ Object
The friendly display title of this checkout link.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCheckoutLinkDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCheckoutLinkDto
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::UpdateCheckoutLinkDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::UpdateCheckoutLinkDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'product_id') self.product_id = attributes[:'product_id'] end if attributes.key?(:'collection_id') self.collection_id = attributes[:'collection_id'] end if attributes.key?(:'customer_name') self.customer_name = attributes[:'customer_name'] end if attributes.key?(:'customer_email') self.customer_email = attributes[:'customer_email'] end if attributes.key?(:'address_line1') self.address_line1 = attributes[:'address_line1'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] end if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.key?(:'cancel_url') self.cancel_url = attributes[:'cancel_url'] end if attributes.key?(:'show_discounts') self.show_discounts = attributes[:'show_discounts'] else self.show_discounts = true end end |
Instance Attribute Details
#address_line1 ⇒ Object
Prefilled customer billing address line 1
34 35 36 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 34 def address_line1 @address_line1 end |
#cancel_url ⇒ Object
The absolute URL to redirect to if a customer cancels the payment
55 56 57 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 55 def cancel_url @cancel_url end |
#city ⇒ Object
Prefilled customer billing city
37 38 39 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 37 def city @city end |
#collection_id ⇒ Object
Optional collection database ID to sell
25 26 27 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 25 def collection_id @collection_id end |
#country ⇒ Object
Prefilled customer billing country (2-letter ISO)
46 47 48 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 46 def country @country end |
#customer_email ⇒ Object
Prefilled customer email for checkout inputs
31 32 33 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 31 def customer_email @customer_email end |
#customer_name ⇒ Object
Prefilled customer name for checkout inputs
28 29 30 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 28 def customer_name @customer_name end |
#postal_code ⇒ Object
Prefilled customer billing zip/postal code
43 44 45 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 43 def postal_code @postal_code end |
#product_id ⇒ Object
Product database/Whop ID to sell
22 23 24 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 22 def product_id @product_id end |
#quantity ⇒ Object
Override quantity for checkout session
49 50 51 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 49 def quantity @quantity end |
#redirect_url ⇒ Object
The absolute URL to redirect to upon successful payment completion
52 53 54 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 52 def redirect_url @redirect_url end |
#show_discounts ⇒ Object
Whether to display discount input form fields on checkout screen
58 59 60 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 58 def show_discounts @show_discounts end |
#state ⇒ Object
Prefilled customer billing state
40 41 42 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 40 def state @state end |
#title ⇒ Object
The friendly display title of this checkout link
19 20 21 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 19 def title @title end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 488 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 81 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 61 def self.attribute_map { :'title' => :'title', :'product_id' => :'productId', :'collection_id' => :'collectionId', :'customer_name' => :'customerName', :'customer_email' => :'customerEmail', :'address_line1' => :'addressLine1', :'city' => :'city', :'state' => :'state', :'postal_code' => :'postalCode', :'country' => :'country', :'quantity' => :'quantity', :'redirect_url' => :'redirectUrl', :'cancel_url' => :'cancelUrl', :'show_discounts' => :'showDiscounts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 464 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 106 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 86 def self.openapi_types { :'title' => :'String', :'product_id' => :'String', :'collection_id' => :'String', :'customer_name' => :'String', :'customer_email' => :'String', :'address_line1' => :'String', :'city' => :'String', :'state' => :'String', :'postal_code' => :'String', :'country' => :'String', :'quantity' => :'Object', :'redirect_url' => :'String', :'cancel_url' => :'String', :'show_discounts' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 430 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && product_id == o.product_id && collection_id == o.collection_id && customer_name == o.customer_name && customer_email == o.customer_email && address_line1 == o.address_line1 && city == o.city && state == o.state && postal_code == o.postal_code && country == o.country && quantity == o.quantity && redirect_url == o.redirect_url && cancel_url == o.cancel_url && show_discounts == o.show_discounts end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
559 560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 559 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
451 452 453 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 451 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
457 458 459 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 457 def hash [title, product_id, collection_id, customer_name, customer_email, address_line1, city, state, postal_code, country, quantity, redirect_url, cancel_url, show_discounts].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 187 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@title.nil? && @title.to_s.length > 100 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 100.') end if !@product_id.nil? && @product_id.to_s.length > 50 invalid_properties.push('invalid value for "product_id", the character length must be smaller than or equal to 50.') end if !@collection_id.nil? && @collection_id.to_s.length > 50 invalid_properties.push('invalid value for "collection_id", the character length must be smaller than or equal to 50.') end if !@customer_name.nil? && @customer_name.to_s.length > 100 invalid_properties.push('invalid value for "customer_name", the character length must be smaller than or equal to 100.') end if !@customer_email.nil? && @customer_email.to_s.length > 255 invalid_properties.push('invalid value for "customer_email", the character length must be smaller than or equal to 255.') end if !@address_line1.nil? && @address_line1.to_s.length > 255 invalid_properties.push('invalid value for "address_line1", the character length must be smaller than or equal to 255.') end if !@city.nil? && @city.to_s.length > 100 invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 100.') end if !@state.nil? && @state.to_s.length > 100 invalid_properties.push('invalid value for "state", the character length must be smaller than or equal to 100.') end if !@postal_code.nil? && @postal_code.to_s.length > 20 invalid_properties.push('invalid value for "postal_code", the character length must be smaller than or equal to 20.') end if !@country.nil? && @country.to_s.length > 10 invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 10.') end if !@redirect_url.nil? && @redirect_url.to_s.length > 2048 invalid_properties.push('invalid value for "redirect_url", the character length must be smaller than or equal to 2048.') end if !@cancel_url.nil? && @cancel_url.to_s.length > 2048 invalid_properties.push('invalid value for "cancel_url", the character length must be smaller than or equal to 2048.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
535 536 537 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 535 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
541 542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 541 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
529 530 531 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 529 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/solifyn/models/update_checkout_link_dto.rb', line 243 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@title.nil? && @title.to_s.length > 100 return false if !@product_id.nil? && @product_id.to_s.length > 50 return false if !@collection_id.nil? && @collection_id.to_s.length > 50 return false if !@customer_name.nil? && @customer_name.to_s.length > 100 return false if !@customer_email.nil? && @customer_email.to_s.length > 255 return false if !@address_line1.nil? && @address_line1.to_s.length > 255 return false if !@city.nil? && @city.to_s.length > 100 return false if !@state.nil? && @state.to_s.length > 100 return false if !@postal_code.nil? && @postal_code.to_s.length > 20 return false if !@country.nil? && @country.to_s.length > 10 return false if !@redirect_url.nil? && @redirect_url.to_s.length > 2048 return false if !@cancel_url.nil? && @cancel_url.to_s.length > 2048 true end |