Class: Solifyn::UpdateEntitlementDto

Inherits:
Object
  • Object
show all
Defined in:
lib/solifyn/models/update_entitlement_dto.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateEntitlementDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::UpdateEntitlementDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::UpdateEntitlementDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'github_repo')
    self.github_repo = attributes[:'github_repo']
  end

  if attributes.key?(:'github_permission')
    self.github_permission = attributes[:'github_permission']
  else
    self.github_permission = 'pull'
  end

  if attributes.key?(:'discord_guild_id')
    self.discord_guild_id = attributes[:'discord_guild_id']
  end

  if attributes.key?(:'discord_role_id')
    self.discord_role_id = attributes[:'discord_role_id']
  end

  if attributes.key?(:'framer_template_id')
    self.framer_template_id = attributes[:'framer_template_id']
  end

  if attributes.key?(:'license_key')
    self.license_key = attributes[:'license_key']
  end

  if attributes.key?(:'activation_limit')
    self.activation_limit = attributes[:'activation_limit']
  end

  if attributes.key?(:'activation_message')
    self.activation_message = attributes[:'activation_message']
  end

  if attributes.key?(:'expiry_hours')
    self.expiry_hours = attributes[:'expiry_hours']
  end

  if attributes.key?(:'digital_link')
    self.digital_link = attributes[:'digital_link']
  end

  if attributes.key?(:'instructions')
    self.instructions = attributes[:'instructions']
  end
end

Instance Attribute Details

#activation_limitObject

The maximum activation limit for licenses



43
44
45
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 43

def activation_limit
  @activation_limit
end

#activation_messageObject

A message shown to the user upon license activation



46
47
48
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 46

def activation_message
  @activation_message
end

The digital download URL or redirect link



52
53
54
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 52

def digital_link
  @digital_link
end

#discord_guild_idObject

The Discord Guild/Server ID



31
32
33
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 31

def discord_guild_id
  @discord_guild_id
end

#discord_role_idObject

The Discord Role ID to assign



34
35
36
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 34

def discord_role_id
  @discord_role_id
end

#expiry_hoursObject

The number of hours until the entitlement expires



49
50
51
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 49

def expiry_hours
  @expiry_hours
end

#framer_template_idObject

The associated Framer Template ID



37
38
39
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 37

def framer_template_id
  @framer_template_id
end

#github_permissionObject

The GitHub repository permission level



28
29
30
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 28

def github_permission
  @github_permission
end

#github_repoObject

The GitHub repository (e.g., owner/repo)



25
26
27
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 25

def github_repo
  @github_repo
end

#instructionsObject

Custom setup instructions for the user



55
56
57
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 55

def instructions
  @instructions
end

#license_keyObject

The static License Key (if not dynamically generated)



40
41
42
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 40

def license_key
  @license_key
end

#nameObject

The user-friendly name of the entitlement



19
20
21
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 19

def name
  @name
end

#typeObject

The type of access to grant



22
23
24
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 22

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 284

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Solifyn.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 99

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 80

def self.attribute_map
  {
    :'name' => :'name',
    :'type' => :'type',
    :'github_repo' => :'githubRepo',
    :'github_permission' => :'githubPermission',
    :'discord_guild_id' => :'discordGuildId',
    :'discord_role_id' => :'discordRoleId',
    :'framer_template_id' => :'framerTemplateId',
    :'license_key' => :'licenseKey',
    :'activation_limit' => :'activationLimit',
    :'activation_message' => :'activationMessage',
    :'expiry_hours' => :'expiryHours',
    :'digital_link' => :'digitalLink',
    :'instructions' => :'instructions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 260

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 123

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 104

def self.openapi_types
  {
    :'name' => :'String',
    :'type' => :'String',
    :'github_repo' => :'String',
    :'github_permission' => :'String',
    :'discord_guild_id' => :'String',
    :'discord_role_id' => :'String',
    :'framer_template_id' => :'String',
    :'license_key' => :'String',
    :'activation_limit' => :'Float',
    :'activation_message' => :'String',
    :'expiry_hours' => :'Float',
    :'digital_link' => :'String',
    :'instructions' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 227

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      type == o.type &&
      github_repo == o.github_repo &&
      github_permission == o.github_permission &&
      discord_guild_id == o.discord_guild_id &&
      discord_role_id == o.discord_role_id &&
      framer_template_id == o.framer_template_id &&
      license_key == o.license_key &&
      activation_limit == o.activation_limit &&
      activation_message == o.activation_message &&
      expiry_hours == o.expiry_hours &&
      digital_link == o.digital_link &&
      instructions == o.instructions
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 355

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



253
254
255
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 253

def hash
  [name, type, github_repo, github_permission, discord_guild_id, discord_role_id, framer_template_id, license_key, activation_limit, activation_message, expiry_hours, digital_link, instructions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



200
201
202
203
204
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 200

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 331

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



325
326
327
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 325

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
# File 'lib/solifyn/models/update_entitlement_dto.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["GITHUB", "DISCORD", "FRAMER", "LICENSE", "DIGITAL"])
  return false unless type_validator.valid?(@type)
  true
end