Class: Solifyn::UpdateMeterDto
- Inherits:
-
Object
- Object
- Solifyn::UpdateMeterDto
- Defined in:
- lib/solifyn/models/update_meter_dto.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aggregation_key ⇒ Object
Metadata key used by SUM, MAX, or LAST aggregation modes.
-
#aggregation_type ⇒ Object
Aggregation strategy for usage events.
-
#description ⇒ Object
Meter description.
-
#enable_filtering ⇒ Object
Enable filtering on usage event ingestion.
-
#event_name ⇒ Object
The event name tracked by this meter.
-
#filters ⇒ Object
Optional filter definition for advanced matching.
-
#name ⇒ Object
Meter display name.
-
#unit ⇒ Object
Measurement unit label.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateMeterDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateMeterDto
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::UpdateMeterDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::UpdateMeterDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'event_name') self.event_name = attributes[:'event_name'] end if attributes.key?(:'aggregation_type') self.aggregation_type = attributes[:'aggregation_type'] end if attributes.key?(:'aggregation_key') self.aggregation_key = attributes[:'aggregation_key'] end if attributes.key?(:'unit') self.unit = attributes[:'unit'] end if attributes.key?(:'filters') if (value = attributes[:'filters']).is_a?(Hash) self.filters = value end end if attributes.key?(:'enable_filtering') self.enable_filtering = attributes[:'enable_filtering'] end end |
Instance Attribute Details
#aggregation_key ⇒ Object
Metadata key used by SUM, MAX, or LAST aggregation modes.
31 32 33 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 31 def aggregation_key @aggregation_key end |
#aggregation_type ⇒ Object
Aggregation strategy for usage events.
28 29 30 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 28 def aggregation_type @aggregation_type end |
#description ⇒ Object
Meter description.
22 23 24 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 22 def description @description end |
#enable_filtering ⇒ Object
Enable filtering on usage event ingestion.
40 41 42 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 40 def enable_filtering @enable_filtering end |
#event_name ⇒ Object
The event name tracked by this meter.
25 26 27 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 25 def event_name @event_name end |
#filters ⇒ Object
Optional filter definition for advanced matching.
37 38 39 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 37 def filters @filters end |
#name ⇒ Object
Meter display name.
19 20 21 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 19 def name @name end |
#unit ⇒ Object
Measurement unit label.
34 35 36 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 34 def unit @unit end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 234 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 79 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 65 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'event_name' => :'eventName', :'aggregation_type' => :'aggregationType', :'aggregation_key' => :'aggregationKey', :'unit' => :'unit', :'filters' => :'filters', :'enable_filtering' => :'enableFiltering' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 84 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'event_name' => :'String', :'aggregation_type' => :'String', :'aggregation_key' => :'String', :'unit' => :'String', :'filters' => :'Hash<String, Object>', :'enable_filtering' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 182 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && event_name == o.event_name && aggregation_type == o.aggregation_type && aggregation_key == o.aggregation_key && unit == o.unit && filters == o.filters && enable_filtering == o.enable_filtering end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 305 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 203 def hash [name, description, event_name, aggregation_type, aggregation_key, unit, filters, enable_filtering].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
281 282 283 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 281 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
275 276 277 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 275 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 |
# File 'lib/solifyn/models/update_meter_dto.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' aggregation_type_validator = EnumAttributeValidator.new('String', ["COUNT", "SUM", "MAX", "LAST"]) return false unless aggregation_type_validator.valid?(@aggregation_type) true end |