Class: Solifyn::UserProfileThemesApi
- Inherits:
-
Object
- Object
- Solifyn::UserProfileThemesApi
- Defined in:
- lib/solifyn/api/user_profile_themes_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ UserProfileThemesApi
constructor
A new instance of UserProfileThemesApi.
-
#users_get_my_page(opts = {}) ⇒ UserPage
Get My Page details Retrieve page settings and custom content configured for the store.
-
#users_get_my_page_with_http_info(opts = {}) ⇒ Array<(UserPage, Integer, Hash)>
Get My Page details Retrieve page settings and custom content configured for the store.
-
#users_get_my_theme(opts = {}) ⇒ UserTheme
Get My Theme Retrieve theme configurations for the active business context.
-
#users_get_my_theme_with_http_info(opts = {}) ⇒ Array<(UserTheme, Integer, Hash)>
Get My Theme Retrieve theme configurations for the active business context.
-
#users_get_settings(opts = {}) ⇒ UserSettings
Retrieve User Settings Retrieve profile settings and notification preferences for the user.
-
#users_get_settings_with_http_info(opts = {}) ⇒ Array<(UserSettings, Integer, Hash)>
Retrieve User Settings Retrieve profile settings and notification preferences for the user.
-
#users_get_stats(opts = {}) ⇒ UserStats
Get Dashboard Statistics Retrieve general analytics stats (revenue, order counts, etc.) for dashboard graphs.
-
#users_get_stats_with_http_info(opts = {}) ⇒ Array<(UserStats, Integer, Hash)>
Get Dashboard Statistics Retrieve general analytics stats (revenue, order counts, etc.) for dashboard graphs.
-
#users_get_theme_by_subdomain(subdomain, opts = {}) ⇒ UserTheme
Get Theme by Subdomain Retrieve public theme configuration details by store subdomain.
-
#users_get_theme_by_subdomain_with_http_info(subdomain, opts = {}) ⇒ Array<(UserTheme, Integer, Hash)>
Get Theme by Subdomain Retrieve public theme configuration details by store subdomain.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UserProfileThemesApi
Returns a new instance of UserProfileThemesApi.
19 20 21 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#users_get_my_page(opts = {}) ⇒ UserPage
Get My Page details Retrieve page settings and custom content configured for the store.
26 27 28 29 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 26 def users_get_my_page(opts = {}) data, _status_code, _headers = users_get_my_page_with_http_info(opts) data end |
#users_get_my_page_with_http_info(opts = {}) ⇒ Array<(UserPage, Integer, Hash)>
Get My Page details Retrieve page settings and custom content configured for the store.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 35 def users_get_my_page_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserProfileThemesApi.users_get_my_page ...' end # resource path local_var_path = '/v1/user/my-page' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserPage' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"UserProfileThemesApi.users_get_my_page", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserProfileThemesApi#users_get_my_page\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#users_get_my_theme(opts = {}) ⇒ UserTheme
Get My Theme Retrieve theme configurations for the active business context.
83 84 85 86 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 83 def users_get_my_theme(opts = {}) data, _status_code, _headers = users_get_my_theme_with_http_info(opts) data end |
#users_get_my_theme_with_http_info(opts = {}) ⇒ Array<(UserTheme, Integer, Hash)>
Get My Theme Retrieve theme configurations for the active business context.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 92 def users_get_my_theme_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserProfileThemesApi.users_get_my_theme ...' end # resource path local_var_path = '/v1/user/my-theme' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserTheme' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"UserProfileThemesApi.users_get_my_theme", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserProfileThemesApi#users_get_my_theme\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#users_get_settings(opts = {}) ⇒ UserSettings
Retrieve User Settings Retrieve profile settings and notification preferences for the user.
140 141 142 143 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 140 def users_get_settings(opts = {}) data, _status_code, _headers = users_get_settings_with_http_info(opts) data end |
#users_get_settings_with_http_info(opts = {}) ⇒ Array<(UserSettings, Integer, Hash)>
Retrieve User Settings Retrieve profile settings and notification preferences for the user.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 149 def users_get_settings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserProfileThemesApi.users_get_settings ...' end # resource path local_var_path = '/v1/user/settings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserSettings' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"UserProfileThemesApi.users_get_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserProfileThemesApi#users_get_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#users_get_stats(opts = {}) ⇒ UserStats
Get Dashboard Statistics Retrieve general analytics stats (revenue, order counts, etc.) for dashboard graphs.
197 198 199 200 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 197 def users_get_stats(opts = {}) data, _status_code, _headers = users_get_stats_with_http_info(opts) data end |
#users_get_stats_with_http_info(opts = {}) ⇒ Array<(UserStats, Integer, Hash)>
Get Dashboard Statistics Retrieve general analytics stats (revenue, order counts, etc.) for dashboard graphs.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 206 def users_get_stats_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserProfileThemesApi.users_get_stats ...' end # resource path local_var_path = '/v1/user/dashboard-stats' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserStats' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"UserProfileThemesApi.users_get_stats", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserProfileThemesApi#users_get_stats\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#users_get_theme_by_subdomain(subdomain, opts = {}) ⇒ UserTheme
Get Theme by Subdomain Retrieve public theme configuration details by store subdomain.
255 256 257 258 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 255 def users_get_theme_by_subdomain(subdomain, opts = {}) data, _status_code, _headers = users_get_theme_by_subdomain_with_http_info(subdomain, opts) data end |
#users_get_theme_by_subdomain_with_http_info(subdomain, opts = {}) ⇒ Array<(UserTheme, Integer, Hash)>
Get Theme by Subdomain Retrieve public theme configuration details by store subdomain.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/solifyn/api/user_profile_themes_api.rb', line 265 def users_get_theme_by_subdomain_with_http_info(subdomain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserProfileThemesApi.users_get_theme_by_subdomain ...' end # verify the required parameter 'subdomain' is set if @api_client.config.client_side_validation && subdomain.nil? fail ArgumentError, "Missing the required parameter 'subdomain' when calling UserProfileThemesApi.users_get_theme_by_subdomain" end # resource path local_var_path = '/v1/user/theme/{subdomain}'.sub('{' + 'subdomain' + '}', CGI.escape(subdomain.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserTheme' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"UserProfileThemesApi.users_get_theme_by_subdomain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserProfileThemesApi#users_get_theme_by_subdomain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |