Class: Solifyn::UserSettingsUpdate
- Inherits:
-
Object
- Object
- Solifyn::UserSettingsUpdate
- Defined in:
- lib/solifyn/models/user_settings_update.rb
Instance Attribute Summary collapse
-
#avatar_url ⇒ Object
User profile avatar URL.
-
#business_title ⇒ Object
Name of the business entity.
-
#default_currency ⇒ Object
Three-letter currency symbol.
-
#email ⇒ Object
User contact email.
-
#favicon_url ⇒ Object
Favicon image URL.
-
#first_name ⇒ Object
User first name.
-
#google_analytics_id ⇒ Object
Google Analytics 4 Property ID.
-
#google_tag_manager_id ⇒ Object
Google Tag Manager Container ID.
-
#last_name ⇒ Object
User last name.
-
#logo_url ⇒ Object
Company/Store logo image URL.
-
#meta_pixel_id ⇒ Object
Facebook Meta Pixel ID.
-
#notify_on_payment_failed ⇒ Object
Send email notifications when payment fails.
-
#notify_on_refund_successful ⇒ Object
Send email notifications when refund is successful.
-
#notify_on_subscription_cancelled ⇒ Object
Send email notifications when subscription is cancelled.
-
#notify_on_subscription_paused ⇒ Object
Send email notifications when subscription is paused.
-
#notify_on_subscription_plan_changed ⇒ Object
Send email notifications on subscription plan changes.
-
#notify_on_subscription_renewal_failed ⇒ Object
Send email notifications when subscription renewal fails.
-
#notify_on_subscription_set_to_cancel ⇒ Object
Send email notifications when subscription is set to cancel.
-
#notify_on_subscription_trial_ending ⇒ Object
Send email notifications when subscription trial is ending.
-
#notify_on_success ⇒ Object
Send email notifications on successful payments.
-
#page_title ⇒ Object
SEO title tag of the store page.
-
#payout_threshold ⇒ Object
Minimum balance required for automatic payouts in cents.
-
#send_digital_file_email ⇒ Object
Send download links automatically via email.
-
#send_license_key_email ⇒ Object
Send license keys automatically via email.
-
#seo_description ⇒ Object
SEO description meta tag.
-
#seo_image ⇒ Object
SEO preview image URL.
-
#social_links ⇒ Object
JSON structure listing social/contact URLs.
-
#statement_descriptor ⇒ Object
Credit card statement descriptor.
-
#store_name ⇒ Object
The store name shown to customers.
-
#subdomain ⇒ Object
The custom store subdomain.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserSettingsUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UserSettingsUpdate
Initializes the object
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/solifyn/models/user_settings_update.rb', line 193 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::UserSettingsUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::UserSettingsUpdate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'subdomain') self.subdomain = attributes[:'subdomain'] end if attributes.key?(:'store_name') self.store_name = attributes[:'store_name'] end if attributes.key?(:'social_links') self. = attributes[:'social_links'] end if attributes.key?(:'page_title') self.page_title = attributes[:'page_title'] end if attributes.key?(:'seo_description') self.seo_description = attributes[:'seo_description'] end if attributes.key?(:'seo_image') self.seo_image = attributes[:'seo_image'] end if attributes.key?(:'favicon_url') self.favicon_url = attributes[:'favicon_url'] end if attributes.key?(:'google_analytics_id') self.google_analytics_id = attributes[:'google_analytics_id'] end if attributes.key?(:'google_tag_manager_id') self.google_tag_manager_id = attributes[:'google_tag_manager_id'] end if attributes.key?(:'meta_pixel_id') self. = attributes[:'meta_pixel_id'] end if attributes.key?(:'logo_url') self.logo_url = attributes[:'logo_url'] end if attributes.key?(:'business_title') self.business_title = attributes[:'business_title'] end if attributes.key?(:'statement_descriptor') self.statement_descriptor = attributes[:'statement_descriptor'] end if attributes.key?(:'default_currency') self.default_currency = attributes[:'default_currency'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'avatar_url') self.avatar_url = attributes[:'avatar_url'] end if attributes.key?(:'payout_threshold') self.payout_threshold = attributes[:'payout_threshold'] end if attributes.key?(:'notify_on_success') self.notify_on_success = attributes[:'notify_on_success'] end if attributes.key?(:'send_license_key_email') self.send_license_key_email = attributes[:'send_license_key_email'] end if attributes.key?(:'send_digital_file_email') self.send_digital_file_email = attributes[:'send_digital_file_email'] end if attributes.key?(:'notify_on_subscription_plan_changed') self.notify_on_subscription_plan_changed = attributes[:'notify_on_subscription_plan_changed'] end if attributes.key?(:'notify_on_subscription_set_to_cancel') self.notify_on_subscription_set_to_cancel = attributes[:'notify_on_subscription_set_to_cancel'] end if attributes.key?(:'notify_on_subscription_cancelled') self.notify_on_subscription_cancelled = attributes[:'notify_on_subscription_cancelled'] end if attributes.key?(:'notify_on_refund_successful') self.notify_on_refund_successful = attributes[:'notify_on_refund_successful'] end if attributes.key?(:'notify_on_payment_failed') self.notify_on_payment_failed = attributes[:'notify_on_payment_failed'] end if attributes.key?(:'notify_on_subscription_renewal_failed') self.notify_on_subscription_renewal_failed = attributes[:'notify_on_subscription_renewal_failed'] end if attributes.key?(:'notify_on_subscription_trial_ending') self.notify_on_subscription_trial_ending = attributes[:'notify_on_subscription_trial_ending'] end if attributes.key?(:'notify_on_subscription_paused') self.notify_on_subscription_paused = attributes[:'notify_on_subscription_paused'] end end |
Instance Attribute Details
#avatar_url ⇒ Object
User profile avatar URL
70 71 72 |
# File 'lib/solifyn/models/user_settings_update.rb', line 70 def avatar_url @avatar_url end |
#business_title ⇒ Object
Name of the business entity
52 53 54 |
# File 'lib/solifyn/models/user_settings_update.rb', line 52 def business_title @business_title end |
#default_currency ⇒ Object
Three-letter currency symbol
58 59 60 |
# File 'lib/solifyn/models/user_settings_update.rb', line 58 def default_currency @default_currency end |
#email ⇒ Object
User contact email
61 62 63 |
# File 'lib/solifyn/models/user_settings_update.rb', line 61 def email @email end |
#favicon_url ⇒ Object
Favicon image URL
37 38 39 |
# File 'lib/solifyn/models/user_settings_update.rb', line 37 def favicon_url @favicon_url end |
#first_name ⇒ Object
User first name
64 65 66 |
# File 'lib/solifyn/models/user_settings_update.rb', line 64 def first_name @first_name end |
#google_analytics_id ⇒ Object
Google Analytics 4 Property ID
40 41 42 |
# File 'lib/solifyn/models/user_settings_update.rb', line 40 def google_analytics_id @google_analytics_id end |
#google_tag_manager_id ⇒ Object
Google Tag Manager Container ID
43 44 45 |
# File 'lib/solifyn/models/user_settings_update.rb', line 43 def google_tag_manager_id @google_tag_manager_id end |
#last_name ⇒ Object
User last name
67 68 69 |
# File 'lib/solifyn/models/user_settings_update.rb', line 67 def last_name @last_name end |
#logo_url ⇒ Object
Company/Store logo image URL
49 50 51 |
# File 'lib/solifyn/models/user_settings_update.rb', line 49 def logo_url @logo_url end |
#meta_pixel_id ⇒ Object
Facebook Meta Pixel ID
46 47 48 |
# File 'lib/solifyn/models/user_settings_update.rb', line 46 def @meta_pixel_id end |
#notify_on_payment_failed ⇒ Object
Send email notifications when payment fails
97 98 99 |
# File 'lib/solifyn/models/user_settings_update.rb', line 97 def notify_on_payment_failed @notify_on_payment_failed end |
#notify_on_refund_successful ⇒ Object
Send email notifications when refund is successful
94 95 96 |
# File 'lib/solifyn/models/user_settings_update.rb', line 94 def notify_on_refund_successful @notify_on_refund_successful end |
#notify_on_subscription_cancelled ⇒ Object
Send email notifications when subscription is cancelled
91 92 93 |
# File 'lib/solifyn/models/user_settings_update.rb', line 91 def notify_on_subscription_cancelled @notify_on_subscription_cancelled end |
#notify_on_subscription_paused ⇒ Object
Send email notifications when subscription is paused
106 107 108 |
# File 'lib/solifyn/models/user_settings_update.rb', line 106 def notify_on_subscription_paused @notify_on_subscription_paused end |
#notify_on_subscription_plan_changed ⇒ Object
Send email notifications on subscription plan changes
85 86 87 |
# File 'lib/solifyn/models/user_settings_update.rb', line 85 def notify_on_subscription_plan_changed @notify_on_subscription_plan_changed end |
#notify_on_subscription_renewal_failed ⇒ Object
Send email notifications when subscription renewal fails
100 101 102 |
# File 'lib/solifyn/models/user_settings_update.rb', line 100 def notify_on_subscription_renewal_failed @notify_on_subscription_renewal_failed end |
#notify_on_subscription_set_to_cancel ⇒ Object
Send email notifications when subscription is set to cancel
88 89 90 |
# File 'lib/solifyn/models/user_settings_update.rb', line 88 def notify_on_subscription_set_to_cancel @notify_on_subscription_set_to_cancel end |
#notify_on_subscription_trial_ending ⇒ Object
Send email notifications when subscription trial is ending
103 104 105 |
# File 'lib/solifyn/models/user_settings_update.rb', line 103 def notify_on_subscription_trial_ending @notify_on_subscription_trial_ending end |
#notify_on_success ⇒ Object
Send email notifications on successful payments
76 77 78 |
# File 'lib/solifyn/models/user_settings_update.rb', line 76 def notify_on_success @notify_on_success end |
#page_title ⇒ Object
SEO title tag of the store page
28 29 30 |
# File 'lib/solifyn/models/user_settings_update.rb', line 28 def page_title @page_title end |
#payout_threshold ⇒ Object
Minimum balance required for automatic payouts in cents
73 74 75 |
# File 'lib/solifyn/models/user_settings_update.rb', line 73 def payout_threshold @payout_threshold end |
#send_digital_file_email ⇒ Object
Send download links automatically via email
82 83 84 |
# File 'lib/solifyn/models/user_settings_update.rb', line 82 def send_digital_file_email @send_digital_file_email end |
#send_license_key_email ⇒ Object
Send license keys automatically via email
79 80 81 |
# File 'lib/solifyn/models/user_settings_update.rb', line 79 def send_license_key_email @send_license_key_email end |
#seo_description ⇒ Object
SEO description meta tag
31 32 33 |
# File 'lib/solifyn/models/user_settings_update.rb', line 31 def seo_description @seo_description end |
#seo_image ⇒ Object
SEO preview image URL
34 35 36 |
# File 'lib/solifyn/models/user_settings_update.rb', line 34 def seo_image @seo_image end |
#social_links ⇒ Object
JSON structure listing social/contact URLs
25 26 27 |
# File 'lib/solifyn/models/user_settings_update.rb', line 25 def @social_links end |
#statement_descriptor ⇒ Object
Credit card statement descriptor
55 56 57 |
# File 'lib/solifyn/models/user_settings_update.rb', line 55 def statement_descriptor @statement_descriptor end |
#store_name ⇒ Object
The store name shown to customers
22 23 24 |
# File 'lib/solifyn/models/user_settings_update.rb', line 22 def store_name @store_name end |
#subdomain ⇒ Object
The custom store subdomain
19 20 21 |
# File 'lib/solifyn/models/user_settings_update.rb', line 19 def subdomain @subdomain end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/solifyn/models/user_settings_update.rb', line 418 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
145 146 147 |
# File 'lib/solifyn/models/user_settings_update.rb', line 145 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/solifyn/models/user_settings_update.rb', line 109 def self.attribute_map { :'subdomain' => :'subdomain', :'store_name' => :'storeName', :'social_links' => :'socialLinks', :'page_title' => :'pageTitle', :'seo_description' => :'seoDescription', :'seo_image' => :'seoImage', :'favicon_url' => :'faviconUrl', :'google_analytics_id' => :'googleAnalyticsId', :'google_tag_manager_id' => :'googleTagManagerId', :'meta_pixel_id' => :'metaPixelId', :'logo_url' => :'logoUrl', :'business_title' => :'businessTitle', :'statement_descriptor' => :'statementDescriptor', :'default_currency' => :'defaultCurrency', :'email' => :'email', :'first_name' => :'firstName', :'last_name' => :'lastName', :'avatar_url' => :'avatarUrl', :'payout_threshold' => :'payoutThreshold', :'notify_on_success' => :'notifyOnSuccess', :'send_license_key_email' => :'sendLicenseKeyEmail', :'send_digital_file_email' => :'sendDigitalFileEmail', :'notify_on_subscription_plan_changed' => :'notifyOnSubscriptionPlanChanged', :'notify_on_subscription_set_to_cancel' => :'notifyOnSubscriptionSetToCancel', :'notify_on_subscription_cancelled' => :'notifyOnSubscriptionCancelled', :'notify_on_refund_successful' => :'notifyOnRefundSuccessful', :'notify_on_payment_failed' => :'notifyOnPaymentFailed', :'notify_on_subscription_renewal_failed' => :'notifyOnSubscriptionRenewalFailed', :'notify_on_subscription_trial_ending' => :'notifyOnSubscriptionTrialEnding', :'notify_on_subscription_paused' => :'notifyOnSubscriptionPaused' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/solifyn/models/user_settings_update.rb', line 394 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
186 187 188 189 |
# File 'lib/solifyn/models/user_settings_update.rb', line 186 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/solifyn/models/user_settings_update.rb', line 150 def self.openapi_types { :'subdomain' => :'String', :'store_name' => :'String', :'social_links' => :'Object', :'page_title' => :'String', :'seo_description' => :'String', :'seo_image' => :'String', :'favicon_url' => :'String', :'google_analytics_id' => :'String', :'google_tag_manager_id' => :'String', :'meta_pixel_id' => :'String', :'logo_url' => :'String', :'business_title' => :'String', :'statement_descriptor' => :'String', :'default_currency' => :'String', :'email' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'avatar_url' => :'String', :'payout_threshold' => :'Float', :'notify_on_success' => :'Boolean', :'send_license_key_email' => :'Boolean', :'send_digital_file_email' => :'Boolean', :'notify_on_subscription_plan_changed' => :'Boolean', :'notify_on_subscription_set_to_cancel' => :'Boolean', :'notify_on_subscription_cancelled' => :'Boolean', :'notify_on_refund_successful' => :'Boolean', :'notify_on_payment_failed' => :'Boolean', :'notify_on_subscription_renewal_failed' => :'Boolean', :'notify_on_subscription_trial_ending' => :'Boolean', :'notify_on_subscription_paused' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/solifyn/models/user_settings_update.rb', line 344 def ==(o) return true if self.equal?(o) self.class == o.class && subdomain == o.subdomain && store_name == o.store_name && == o. && page_title == o.page_title && seo_description == o.seo_description && seo_image == o.seo_image && favicon_url == o.favicon_url && google_analytics_id == o.google_analytics_id && google_tag_manager_id == o.google_tag_manager_id && == o. && logo_url == o.logo_url && business_title == o.business_title && statement_descriptor == o.statement_descriptor && default_currency == o.default_currency && email == o.email && first_name == o.first_name && last_name == o.last_name && avatar_url == o.avatar_url && payout_threshold == o.payout_threshold && notify_on_success == o.notify_on_success && send_license_key_email == o.send_license_key_email && send_digital_file_email == o.send_digital_file_email && notify_on_subscription_plan_changed == o.notify_on_subscription_plan_changed && notify_on_subscription_set_to_cancel == o.notify_on_subscription_set_to_cancel && notify_on_subscription_cancelled == o.notify_on_subscription_cancelled && notify_on_refund_successful == o.notify_on_refund_successful && notify_on_payment_failed == o.notify_on_payment_failed && notify_on_subscription_renewal_failed == o.notify_on_subscription_renewal_failed && notify_on_subscription_trial_ending == o.notify_on_subscription_trial_ending && notify_on_subscription_paused == o.notify_on_subscription_paused end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/solifyn/models/user_settings_update.rb', line 489 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
381 382 383 |
# File 'lib/solifyn/models/user_settings_update.rb', line 381 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
387 388 389 |
# File 'lib/solifyn/models/user_settings_update.rb', line 387 def hash [subdomain, store_name, , page_title, seo_description, seo_image, favicon_url, google_analytics_id, google_tag_manager_id, , logo_url, business_title, statement_descriptor, default_currency, email, first_name, last_name, avatar_url, payout_threshold, notify_on_success, send_license_key_email, send_digital_file_email, notify_on_subscription_plan_changed, notify_on_subscription_set_to_cancel, notify_on_subscription_cancelled, notify_on_refund_successful, notify_on_payment_failed, notify_on_subscription_renewal_failed, notify_on_subscription_trial_ending, notify_on_subscription_paused].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
329 330 331 332 333 |
# File 'lib/solifyn/models/user_settings_update.rb', line 329 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
465 466 467 |
# File 'lib/solifyn/models/user_settings_update.rb', line 465 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/solifyn/models/user_settings_update.rb', line 471 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
459 460 461 |
# File 'lib/solifyn/models/user_settings_update.rb', line 459 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
337 338 339 340 |
# File 'lib/solifyn/models/user_settings_update.rb', line 337 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |