Class: Solifyn::WebhookEntitlementGrantPayload
- Inherits:
-
Object
- Object
- Solifyn::WebhookEntitlementGrantPayload
- Defined in:
- lib/solifyn/models/webhook_entitlement_grant_payload.rb
Instance Attribute Summary collapse
-
#business_id ⇒ Object
The business ID context.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#customer_id ⇒ Object
The customer ID.
-
#error_details ⇒ Object
Error message if invitation delivery failed.
-
#github_permission ⇒ Object
GitHub access permission level if type is GITHUB.
-
#github_repo ⇒ Object
Target GitHub repository (owner/repo) if type is GITHUB.
-
#github_username ⇒ Object
The connected customer GitHub username.
-
#id ⇒ Object
The unique entitlement grant ID.
-
#oauth_url ⇒ Object
OAuth URL to redirect the customer to.
-
#payment_id ⇒ Object
Associated payment transaction ID.
-
#product_id ⇒ Object
The purchased product ID.
-
#status ⇒ Object
Delivery status of the collaborator invite (PENDING, DELIVERED, FAILED, REVOKED).
-
#type ⇒ Object
The type of entitlement (e.g. GITHUB).
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookEntitlementGrantPayload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WebhookEntitlementGrantPayload
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::WebhookEntitlementGrantPayload` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::WebhookEntitlementGrantPayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'business_id') self.business_id = attributes[:'business_id'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'payment_id') self.payment_id = attributes[:'payment_id'] end if attributes.key?(:'product_id') self.product_id = attributes[:'product_id'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'github_repo') self.github_repo = attributes[:'github_repo'] end if attributes.key?(:'github_permission') self. = attributes[:'github_permission'] end if attributes.key?(:'github_username') self.github_username = attributes[:'github_username'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'oauth_url') self.oauth_url = attributes[:'oauth_url'] end if attributes.key?(:'error_details') self.error_details = attributes[:'error_details'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#business_id ⇒ Object
The business ID context.
22 23 24 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 22 def business_id @business_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
54 55 56 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 54 def created_at @created_at end |
#customer_id ⇒ Object
The customer ID.
25 26 27 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 25 def customer_id @customer_id end |
#error_details ⇒ Object
Error message if invitation delivery failed.
52 53 54 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 52 def error_details @error_details end |
#github_permission ⇒ Object
GitHub access permission level if type is GITHUB.
40 41 42 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 40 def @github_permission end |
#github_repo ⇒ Object
Target GitHub repository (owner/repo) if type is GITHUB.
37 38 39 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 37 def github_repo @github_repo end |
#github_username ⇒ Object
The connected customer GitHub username.
43 44 45 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 43 def github_username @github_username end |
#id ⇒ Object
The unique entitlement grant ID.
19 20 21 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 19 def id @id end |
#oauth_url ⇒ Object
OAuth URL to redirect the customer to.
49 50 51 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 49 def oauth_url @oauth_url end |
#payment_id ⇒ Object
Associated payment transaction ID.
28 29 30 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 28 def payment_id @payment_id end |
#product_id ⇒ Object
The purchased product ID.
31 32 33 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 31 def product_id @product_id end |
#status ⇒ Object
Delivery status of the collaborator invite (PENDING, DELIVERED, FAILED, REVOKED).
46 47 48 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 46 def status @status end |
#type ⇒ Object
The type of entitlement (e.g. GITHUB).
34 35 36 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 34 def type @type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
56 57 58 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 56 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 256 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 79 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 59 def self.attribute_map { :'id' => :'id', :'business_id' => :'businessId', :'customer_id' => :'customerId', :'payment_id' => :'paymentId', :'product_id' => :'productId', :'type' => :'type', :'github_repo' => :'githubRepo', :'github_permission' => :'githubPermission', :'github_username' => :'githubUsername', :'status' => :'status', :'oauth_url' => :'oauthUrl', :'error_details' => :'errorDetails', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 232 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 84 def self.openapi_types { :'id' => :'String', :'business_id' => :'String', :'customer_id' => :'String', :'payment_id' => :'String', :'product_id' => :'String', :'type' => :'String', :'github_repo' => :'String', :'github_permission' => :'String', :'github_username' => :'String', :'status' => :'String', :'oauth_url' => :'String', :'error_details' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && business_id == o.business_id && customer_id == o.customer_id && payment_id == o.payment_id && product_id == o.product_id && type == o.type && github_repo == o.github_repo && == o. && github_username == o.github_username && status == o.status && oauth_url == o.oauth_url && error_details == o.error_details && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 327 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
219 220 221 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 219 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
225 226 227 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 225 def hash [id, business_id, customer_id, payment_id, product_id, type, github_repo, , github_username, status, oauth_url, error_details, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
183 184 185 186 187 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 183 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
303 304 305 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 303 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 297 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 |
# File 'lib/solifyn/models/webhook_entitlement_grant_payload.rb', line 191 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |