Class: Solifyn::WebhookLicensePayload
- Inherits:
-
Object
- Object
- Solifyn::WebhookLicensePayload
- Defined in:
- lib/solifyn/models/webhook_license_payload.rb
Overview
Represents a cryptographically secure software license key issued to a customer upon purchase or manual issuance.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#activation_limit ⇒ Object
Maximum number of simultaneous active device instances allowed for this license.
-
#activation_message ⇒ Object
Optional message displayed to the customer upon successful activation.
-
#archived ⇒ Object
Indicates if the license key is archived.
-
#business_id ⇒ Object
The unique identifier associated with the business this license belongs to.
-
#created_at ⇒ Object
Timestamp indicating exactly when the license key was issued.
-
#customer_id ⇒ Object
The unique customer identifier (ID) who received this license key.
-
#expires_at ⇒ Object
Absolute expiration timestamp.
-
#expiry_hours ⇒ Object
Relative expiry duration in hours from the time of issuance.
-
#filters ⇒ Object
Optional custom metadata filters associated with the license.
-
#id ⇒ Object
The unique prefix-based identifier of the license key.
-
#instances_count ⇒ Object
Running count of how many times this license key has been activated.
-
#key ⇒ Object
The cryptographically generated license key string delivered to the customer.
-
#payment_id ⇒ Object
The unique payment identifier that triggered the issuance of this license key.
-
#product_id ⇒ Object
The unique ID of the product this license key is associated with.
-
#status ⇒ Object
Lifecycle status of the license.
-
#updated_at ⇒ Object
Timestamp indicating when the license key was last modified.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookLicensePayload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WebhookLicensePayload
Initializes the object
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 146 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::WebhookLicensePayload` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::WebhookLicensePayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'business_id') self.business_id = attributes[:'business_id'] else self.business_id = nil end if attributes.key?(:'product_id') self.product_id = attributes[:'product_id'] else self.product_id = nil end if attributes.key?(:'payment_id') self.payment_id = attributes[:'payment_id'] else self.payment_id = nil end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] else self.customer_id = nil end if attributes.key?(:'activation_limit') self.activation_limit = attributes[:'activation_limit'] else self.activation_limit = nil end if attributes.key?(:'activation_message') self. = attributes[:'activation_message'] else self. = nil end if attributes.key?(:'instances_count') self.instances_count = attributes[:'instances_count'] else self.instances_count = nil end if attributes.key?(:'expiry_hours') self.expiry_hours = attributes[:'expiry_hours'] else self.expiry_hours = nil end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'filters') self.filters = attributes[:'filters'] else self.filters = nil end if attributes.key?(:'archived') self.archived = attributes[:'archived'] else self.archived = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#activation_limit ⇒ Object
Maximum number of simultaneous active device instances allowed for this license. Null means unlimited.
41 42 43 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 41 def activation_limit @activation_limit end |
#activation_message ⇒ Object
Optional message displayed to the customer upon successful activation.
44 45 46 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 44 def @activation_message end |
#archived ⇒ Object
Indicates if the license key is archived.
59 60 61 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 59 def archived @archived end |
#business_id ⇒ Object
The unique identifier associated with the business this license belongs to.
29 30 31 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 29 def business_id @business_id end |
#created_at ⇒ Object
Timestamp indicating exactly when the license key was issued.
62 63 64 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 62 def created_at @created_at end |
#customer_id ⇒ Object
The unique customer identifier (ID) who received this license key.
38 39 40 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 38 def customer_id @customer_id end |
#expires_at ⇒ Object
Absolute expiration timestamp. The license becomes invalid after this point.
53 54 55 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 53 def expires_at @expires_at end |
#expiry_hours ⇒ Object
Relative expiry duration in hours from the time of issuance.
50 51 52 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 50 def expiry_hours @expiry_hours end |
#filters ⇒ Object
Optional custom metadata filters associated with the license.
56 57 58 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 56 def filters @filters end |
#id ⇒ Object
The unique prefix-based identifier of the license key.
20 21 22 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 20 def id @id end |
#instances_count ⇒ Object
Running count of how many times this license key has been activated.
47 48 49 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 47 def instances_count @instances_count end |
#key ⇒ Object
The cryptographically generated license key string delivered to the customer.
23 24 25 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 23 def key @key end |
#payment_id ⇒ Object
The unique payment identifier that triggered the issuance of this license key.
35 36 37 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 35 def payment_id @payment_id end |
#product_id ⇒ Object
The unique ID of the product this license key is associated with.
32 33 34 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 32 def product_id @product_id end |
#status ⇒ Object
Lifecycle status of the license. ACTIVE = active. DISABLED = suspended. REVOKED = hard-revoked.
26 27 28 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 26 def status @status end |
#updated_at ⇒ Object
Timestamp indicating when the license key was last modified.
65 66 67 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 65 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 425 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
112 113 114 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 112 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 90 def self.attribute_map { :'id' => :'id', :'key' => :'key', :'status' => :'status', :'business_id' => :'businessId', :'product_id' => :'productId', :'payment_id' => :'paymentId', :'customer_id' => :'customerId', :'activation_limit' => :'activationLimit', :'activation_message' => :'activationMessage', :'instances_count' => :'instancesCount', :'expiry_hours' => :'expiryHours', :'expires_at' => :'expiresAt', :'filters' => :'filters', :'archived' => :'archived', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 401 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
139 140 141 142 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 139 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 117 def self.openapi_types { :'id' => :'String', :'key' => :'String', :'status' => :'String', :'business_id' => :'String', :'product_id' => :'String', :'payment_id' => :'String', :'customer_id' => :'String', :'activation_limit' => :'Float', :'activation_message' => :'String', :'instances_count' => :'Float', :'expiry_hours' => :'Float', :'expires_at' => :'String', :'filters' => :'Object', :'archived' => :'Boolean', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 365 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && key == o.key && status == o.status && business_id == o.business_id && product_id == o.product_id && payment_id == o.payment_id && customer_id == o.customer_id && activation_limit == o.activation_limit && == o. && instances_count == o.instances_count && expiry_hours == o.expiry_hours && expires_at == o.expires_at && filters == o.filters && archived == o.archived && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 496 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
388 389 390 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 388 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
394 395 396 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 394 def hash [id, key, status, business_id, product_id, payment_id, customer_id, activation_limit, , instances_count, expiry_hours, expires_at, filters, archived, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 258 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @business_id.nil? invalid_properties.push('invalid value for "business_id", business_id cannot be nil.') end if @product_id.nil? invalid_properties.push('invalid value for "product_id", product_id cannot be nil.') end if @payment_id.nil? invalid_properties.push('invalid value for "payment_id", payment_id cannot be nil.') end if @customer_id.nil? invalid_properties.push('invalid value for "customer_id", customer_id cannot be nil.') end if @activation_limit.nil? invalid_properties.push('invalid value for "activation_limit", activation_limit cannot be nil.') end if @activation_message.nil? invalid_properties.push('invalid value for "activation_message", activation_message cannot be nil.') end if @instances_count.nil? invalid_properties.push('invalid value for "instances_count", instances_count cannot be nil.') end if @expiry_hours.nil? invalid_properties.push('invalid value for "expiry_hours", expiry_hours cannot be nil.') end if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end if @filters.nil? invalid_properties.push('invalid value for "filters", filters cannot be nil.') end if @archived.nil? invalid_properties.push('invalid value for "archived", archived cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
472 473 474 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 472 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 478 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
466 467 468 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 466 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/solifyn/models/webhook_license_payload.rb', line 330 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @key.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "DISABLED", "REVOKED"]) return false unless status_validator.valid?(@status) return false if @business_id.nil? return false if @product_id.nil? return false if @payment_id.nil? return false if @customer_id.nil? return false if @activation_limit.nil? return false if @activation_message.nil? return false if @instances_count.nil? return false if @expiry_hours.nil? return false if @expires_at.nil? return false if @filters.nil? return false if @archived.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |