Class: Solifyn::Withdrawal
- Inherits:
-
Object
- Object
- Solifyn::Withdrawal
- Defined in:
- lib/solifyn/models/withdrawal.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount withdrawn in cents.
-
#business_id ⇒ Object
The business ID associated with this withdrawal.
-
#created_at ⇒ Object
Timestamp when the withdrawal was requested.
-
#currency ⇒ Object
Three-letter ISO currency code.
-
#error_message ⇒ Object
Error message if the withdrawal failed.
-
#fee_amount ⇒ Object
Fee amount charged for the withdrawal in cents.
-
#fee_type ⇒ Object
The fee structure type (inclusive or exclusive).
-
#id ⇒ Object
The local withdrawal ID.
-
#markup_fee ⇒ Object
Markup fee applied in cents.
-
#payer_name ⇒ Object
The name of the entity or account paying out.
-
#speed ⇒ Object
Speed of withdrawal (standard, instant).
-
#status ⇒ Object
The status of the withdrawal request.
-
#trace_code ⇒ Object
Bank trace or reference code for tracking the payout.
-
#updated_at ⇒ Object
Timestamp when the withdrawal status was updated.
-
#whop_id ⇒ Object
The Whop withdrawal ID.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Withdrawal
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Withdrawal
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/solifyn/models/withdrawal.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::Withdrawal` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::Withdrawal`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'whop_id') self.whop_id = attributes[:'whop_id'] else self.whop_id = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'fee_amount') self.fee_amount = attributes[:'fee_amount'] end if attributes.key?(:'fee_type') self.fee_type = attributes[:'fee_type'] end if attributes.key?(:'markup_fee') self.markup_fee = attributes[:'markup_fee'] end if attributes.key?(:'speed') self.speed = attributes[:'speed'] end if attributes.key?(:'trace_code') self.trace_code = attributes[:'trace_code'] end if attributes.key?(:'payer_name') self.payer_name = attributes[:'payer_name'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'business_id') self.business_id = attributes[:'business_id'] else self.business_id = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#amount ⇒ Object
The amount withdrawn in cents
25 26 27 |
# File 'lib/solifyn/models/withdrawal.rb', line 25 def amount @amount end |
#business_id ⇒ Object
The business ID associated with this withdrawal
55 56 57 |
# File 'lib/solifyn/models/withdrawal.rb', line 55 def business_id @business_id end |
#created_at ⇒ Object
Timestamp when the withdrawal was requested
58 59 60 |
# File 'lib/solifyn/models/withdrawal.rb', line 58 def created_at @created_at end |
#currency ⇒ Object
Three-letter ISO currency code
28 29 30 |
# File 'lib/solifyn/models/withdrawal.rb', line 28 def currency @currency end |
#error_message ⇒ Object
Error message if the withdrawal failed
52 53 54 |
# File 'lib/solifyn/models/withdrawal.rb', line 52 def @error_message end |
#fee_amount ⇒ Object
Fee amount charged for the withdrawal in cents
34 35 36 |
# File 'lib/solifyn/models/withdrawal.rb', line 34 def fee_amount @fee_amount end |
#fee_type ⇒ Object
The fee structure type (inclusive or exclusive)
37 38 39 |
# File 'lib/solifyn/models/withdrawal.rb', line 37 def fee_type @fee_type end |
#id ⇒ Object
The local withdrawal ID
19 20 21 |
# File 'lib/solifyn/models/withdrawal.rb', line 19 def id @id end |
#markup_fee ⇒ Object
Markup fee applied in cents
40 41 42 |
# File 'lib/solifyn/models/withdrawal.rb', line 40 def markup_fee @markup_fee end |
#payer_name ⇒ Object
The name of the entity or account paying out
49 50 51 |
# File 'lib/solifyn/models/withdrawal.rb', line 49 def payer_name @payer_name end |
#speed ⇒ Object
Speed of withdrawal (standard, instant)
43 44 45 |
# File 'lib/solifyn/models/withdrawal.rb', line 43 def speed @speed end |
#status ⇒ Object
The status of the withdrawal request
31 32 33 |
# File 'lib/solifyn/models/withdrawal.rb', line 31 def status @status end |
#trace_code ⇒ Object
Bank trace or reference code for tracking the payout
46 47 48 |
# File 'lib/solifyn/models/withdrawal.rb', line 46 def trace_code @trace_code end |
#updated_at ⇒ Object
Timestamp when the withdrawal status was updated
61 62 63 |
# File 'lib/solifyn/models/withdrawal.rb', line 61 def updated_at @updated_at end |
#whop_id ⇒ Object
The Whop withdrawal ID
22 23 24 |
# File 'lib/solifyn/models/withdrawal.rb', line 22 def whop_id @whop_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/solifyn/models/withdrawal.rb', line 324 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Solifyn.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/solifyn/models/withdrawal.rb', line 85 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/solifyn/models/withdrawal.rb', line 64 def self.attribute_map { :'id' => :'id', :'whop_id' => :'whopId', :'amount' => :'amount', :'currency' => :'currency', :'status' => :'status', :'fee_amount' => :'feeAmount', :'fee_type' => :'feeType', :'markup_fee' => :'markupFee', :'speed' => :'speed', :'trace_code' => :'traceCode', :'payer_name' => :'payerName', :'error_message' => :'errorMessage', :'business_id' => :'businessId', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/solifyn/models/withdrawal.rb', line 300 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/solifyn/models/withdrawal.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/solifyn/models/withdrawal.rb', line 90 def self.openapi_types { :'id' => :'String', :'whop_id' => :'String', :'amount' => :'Float', :'currency' => :'String', :'status' => :'String', :'fee_amount' => :'Float', :'fee_type' => :'String', :'markup_fee' => :'Float', :'speed' => :'String', :'trace_code' => :'String', :'payer_name' => :'String', :'error_message' => :'String', :'business_id' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/solifyn/models/withdrawal.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && whop_id == o.whop_id && amount == o.amount && currency == o.currency && status == o.status && fee_amount == o.fee_amount && fee_type == o.fee_type && markup_fee == o.markup_fee && speed == o.speed && trace_code == o.trace_code && payer_name == o.payer_name && == o. && business_id == o.business_id && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/solifyn/models/withdrawal.rb', line 395 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
287 288 289 |
# File 'lib/solifyn/models/withdrawal.rb', line 287 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
293 294 295 |
# File 'lib/solifyn/models/withdrawal.rb', line 293 def hash [id, whop_id, amount, currency, status, fee_amount, fee_type, markup_fee, speed, trace_code, payer_name, , business_id, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/solifyn/models/withdrawal.rb', line 210 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @whop_id.nil? invalid_properties.push('invalid value for "whop_id", whop_id cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @business_id.nil? invalid_properties.push('invalid value for "business_id", business_id cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
371 372 373 |
# File 'lib/solifyn/models/withdrawal.rb', line 371 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/solifyn/models/withdrawal.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
365 366 367 |
# File 'lib/solifyn/models/withdrawal.rb', line 365 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/solifyn/models/withdrawal.rb', line 250 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @whop_id.nil? return false if @amount.nil? return false if @currency.nil? return false if @status.nil? return false if @business_id.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |