Class: Solifyn::DefaultApi
- Inherits:
-
Object
- Object
- Solifyn::DefaultApi
- Defined in:
- lib/solifyn/api/default_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#dispute_created_post(opts = {}) ⇒ nil
Dispute Created Occurs when a payment charge is disputed by the customer (chargeback initiated).
-
#dispute_created_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Dispute Created Occurs when a payment charge is disputed by the customer (chargeback initiated).
-
#dispute_lost_post(opts = {}) ⇒ nil
Dispute Lost Occurs when a dispute challenge is lost and the funds are returned to the cardholder.
-
#dispute_lost_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Dispute Lost Occurs when a dispute challenge is lost and the funds are returned to the cardholder.
-
#dispute_won_post(opts = {}) ⇒ nil
Dispute Won Occurs when a dispute challenge is won by the merchant.
-
#dispute_won_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Dispute Won Occurs when a dispute challenge is won by the merchant.
-
#initialize(api_client = ApiClient.default) ⇒ DefaultApi
constructor
A new instance of DefaultApi.
-
#license_created_post(opts = {}) ⇒ nil
License Created Occurs when a new software license key is created or assigned to a customer purchase.
-
#license_created_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
License Created Occurs when a new software license key is created or assigned to a customer purchase.
-
#license_revoked_post(opts = {}) ⇒ nil
License Revoked Occurs when a software license key is revoked (e.g., due to subscription cancellation, refund, or dispute).
-
#license_revoked_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
License Revoked Occurs when a software license key is revoked (e.g., due to subscription cancellation, refund, or dispute).
-
#payment_created_post(opts = {}) ⇒ nil
Payment Created Occurs when a new payment is initiated (e.g., at checkout start or subscription creation).
-
#payment_created_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Payment Created Occurs when a new payment is initiated (e.g., at checkout start or subscription creation).
-
#payment_failed_post(opts = {}) ⇒ nil
Payment Failed Occurs when a customer payment attempt fails.
-
#payment_failed_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Payment Failed Occurs when a customer payment attempt fails.
-
#payment_succeeded_post(opts = {}) ⇒ nil
Payment Succeeded Occurs when a customer payment is confirmed as succeeded.
-
#payment_succeeded_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Payment Succeeded Occurs when a customer payment is confirmed as succeeded.
-
#refund_failed_post(opts = {}) ⇒ nil
Refund Failed Occurs when a payment refund fails.
-
#refund_failed_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Refund Failed Occurs when a payment refund fails.
-
#refund_succeeded_post(opts = {}) ⇒ nil
Refund Succeeded Occurs when a payment refund is confirmed as succeeded.
-
#refund_succeeded_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Refund Succeeded Occurs when a payment refund is confirmed as succeeded.
-
#subscription_created_post(opts = {}) ⇒ nil
Subscription Created Occurs when a customer subscription is successfully started.
-
#subscription_created_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Subscription Created Occurs when a customer subscription is successfully started.
-
#subscription_deactivated_post(opts = {}) ⇒ nil
Subscription Deactivated Occurs when a customer subscription is deactivated or expired.
-
#subscription_deactivated_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Subscription Deactivated Occurs when a customer subscription is deactivated or expired.
-
#subscription_updated_post(opts = {}) ⇒ nil
Subscription Updated Occurs when a customer subscription is updated (e.g., cancel at period end changes).
-
#subscription_updated_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Subscription Updated Occurs when a customer subscription is updated (e.g., cancel at period end changes).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DefaultApi
Returns a new instance of DefaultApi.
19 20 21 |
# File 'lib/solifyn/api/default_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/default_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#dispute_created_post(opts = {}) ⇒ nil
Dispute Created Occurs when a payment charge is disputed by the customer (chargeback initiated).
27 28 29 30 |
# File 'lib/solifyn/api/default_api.rb', line 27 def dispute_created_post(opts = {}) dispute_created_post_with_http_info(opts) nil end |
#dispute_created_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Dispute Created Occurs when a payment charge is disputed by the customer (chargeback initiated).
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/solifyn/api/default_api.rb', line 37 def dispute_created_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.dispute_created_post ...' end # resource path local_var_path = '/dispute.created' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_dispute_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.dispute_created_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#dispute_created_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#dispute_lost_post(opts = {}) ⇒ nil
Dispute Lost Occurs when a dispute challenge is lost and the funds are returned to the cardholder.
89 90 91 92 |
# File 'lib/solifyn/api/default_api.rb', line 89 def dispute_lost_post(opts = {}) dispute_lost_post_with_http_info(opts) nil end |
#dispute_lost_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Dispute Lost Occurs when a dispute challenge is lost and the funds are returned to the cardholder.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/solifyn/api/default_api.rb', line 99 def dispute_lost_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.dispute_lost_post ...' end # resource path local_var_path = '/dispute.lost' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_dispute_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.dispute_lost_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#dispute_lost_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#dispute_won_post(opts = {}) ⇒ nil
Dispute Won Occurs when a dispute challenge is won by the merchant.
151 152 153 154 |
# File 'lib/solifyn/api/default_api.rb', line 151 def dispute_won_post(opts = {}) dispute_won_post_with_http_info(opts) nil end |
#dispute_won_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Dispute Won Occurs when a dispute challenge is won by the merchant.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/solifyn/api/default_api.rb', line 161 def dispute_won_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.dispute_won_post ...' end # resource path local_var_path = '/dispute.won' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_dispute_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.dispute_won_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#dispute_won_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#license_created_post(opts = {}) ⇒ nil
License Created Occurs when a new software license key is created or assigned to a customer purchase.
213 214 215 216 |
# File 'lib/solifyn/api/default_api.rb', line 213 def license_created_post(opts = {}) license_created_post_with_http_info(opts) nil end |
#license_created_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
License Created Occurs when a new software license key is created or assigned to a customer purchase.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/solifyn/api/default_api.rb', line 223 def license_created_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.license_created_post ...' end # resource path local_var_path = '/license.created' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_license_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.license_created_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#license_created_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#license_revoked_post(opts = {}) ⇒ nil
License Revoked Occurs when a software license key is revoked (e.g., due to subscription cancellation, refund, or dispute).
275 276 277 278 |
# File 'lib/solifyn/api/default_api.rb', line 275 def license_revoked_post(opts = {}) license_revoked_post_with_http_info(opts) nil end |
#license_revoked_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
License Revoked Occurs when a software license key is revoked (e.g., due to subscription cancellation, refund, or dispute).
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/solifyn/api/default_api.rb', line 285 def license_revoked_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.license_revoked_post ...' end # resource path local_var_path = '/license.revoked' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_license_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.license_revoked_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#license_revoked_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#payment_created_post(opts = {}) ⇒ nil
Payment Created Occurs when a new payment is initiated (e.g., at checkout start or subscription creation). The payment may still be in an incomplete or pending state.
337 338 339 340 |
# File 'lib/solifyn/api/default_api.rb', line 337 def payment_created_post(opts = {}) payment_created_post_with_http_info(opts) nil end |
#payment_created_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Payment Created Occurs when a new payment is initiated (e.g., at checkout start or subscription creation). The payment may still be in an incomplete or pending state.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/solifyn/api/default_api.rb', line 347 def payment_created_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.payment_created_post ...' end # resource path local_var_path = '/payment.created' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_payment_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.payment_created_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#payment_created_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#payment_failed_post(opts = {}) ⇒ nil
Payment Failed Occurs when a customer payment attempt fails.
399 400 401 402 |
# File 'lib/solifyn/api/default_api.rb', line 399 def payment_failed_post(opts = {}) payment_failed_post_with_http_info(opts) nil end |
#payment_failed_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Payment Failed Occurs when a customer payment attempt fails.
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/solifyn/api/default_api.rb', line 409 def payment_failed_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.payment_failed_post ...' end # resource path local_var_path = '/payment.failed' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'order']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.payment_failed_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#payment_failed_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#payment_succeeded_post(opts = {}) ⇒ nil
Payment Succeeded Occurs when a customer payment is confirmed as succeeded.
461 462 463 464 |
# File 'lib/solifyn/api/default_api.rb', line 461 def payment_succeeded_post(opts = {}) payment_succeeded_post_with_http_info(opts) nil end |
#payment_succeeded_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Payment Succeeded Occurs when a customer payment is confirmed as succeeded.
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/solifyn/api/default_api.rb', line 471 def payment_succeeded_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.payment_succeeded_post ...' end # resource path local_var_path = '/payment.succeeded' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'order']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.payment_succeeded_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#payment_succeeded_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#refund_failed_post(opts = {}) ⇒ nil
Refund Failed Occurs when a payment refund fails.
523 524 525 526 |
# File 'lib/solifyn/api/default_api.rb', line 523 def refund_failed_post(opts = {}) refund_failed_post_with_http_info(opts) nil end |
#refund_failed_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Refund Failed Occurs when a payment refund fails.
533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/solifyn/api/default_api.rb', line 533 def refund_failed_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.refund_failed_post ...' end # resource path local_var_path = '/refund.failed' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_refund_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.refund_failed_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#refund_failed_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#refund_succeeded_post(opts = {}) ⇒ nil
Refund Succeeded Occurs when a payment refund is confirmed as succeeded.
585 586 587 588 |
# File 'lib/solifyn/api/default_api.rb', line 585 def refund_succeeded_post(opts = {}) refund_succeeded_post_with_http_info(opts) nil end |
#refund_succeeded_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Refund Succeeded Occurs when a payment refund is confirmed as succeeded.
595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'lib/solifyn/api/default_api.rb', line 595 def refund_succeeded_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.refund_succeeded_post ...' end # resource path local_var_path = '/refund.succeeded' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_refund_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.refund_succeeded_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#refund_succeeded_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#subscription_created_post(opts = {}) ⇒ nil
Subscription Created Occurs when a customer subscription is successfully started.
647 648 649 650 |
# File 'lib/solifyn/api/default_api.rb', line 647 def subscription_created_post(opts = {}) subscription_created_post_with_http_info(opts) nil end |
#subscription_created_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Subscription Created Occurs when a customer subscription is successfully started.
657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/solifyn/api/default_api.rb', line 657 def subscription_created_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.subscription_created_post ...' end # resource path local_var_path = '/subscription.created' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_subscription_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.subscription_created_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#subscription_created_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#subscription_deactivated_post(opts = {}) ⇒ nil
Subscription Deactivated Occurs when a customer subscription is deactivated or expired.
709 710 711 712 |
# File 'lib/solifyn/api/default_api.rb', line 709 def subscription_deactivated_post(opts = {}) subscription_deactivated_post_with_http_info(opts) nil end |
#subscription_deactivated_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Subscription Deactivated Occurs when a customer subscription is deactivated or expired.
719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 |
# File 'lib/solifyn/api/default_api.rb', line 719 def subscription_deactivated_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.subscription_deactivated_post ...' end # resource path local_var_path = '/subscription.deactivated' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_subscription_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.subscription_deactivated_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#subscription_deactivated_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#subscription_updated_post(opts = {}) ⇒ nil
Subscription Updated Occurs when a customer subscription is updated (e.g., cancel at period end changes).
771 772 773 774 |
# File 'lib/solifyn/api/default_api.rb', line 771 def subscription_updated_post(opts = {}) subscription_updated_post_with_http_info(opts) nil end |
#subscription_updated_post_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Subscription Updated Occurs when a customer subscription is updated (e.g., cancel at period end changes).
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 |
# File 'lib/solifyn/api/default_api.rb', line 781 def subscription_updated_post_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DefaultApi.subscription_updated_post ...' end # resource path local_var_path = '/subscription.updated' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'webhook_subscription_payload']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"DefaultApi.subscription_updated_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DefaultApi#subscription_updated_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |