Class: Solifyn::Discount

Inherits:
Object
  • Object
show all
Defined in:
lib/solifyn/models/discount.rb

Overview

Represents a discount code created under your business, containing type, amount, usage limits, and expiration details.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Discount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/solifyn/models/discount.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::Discount` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::Discount`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'discount_id')
    self.discount_id = attributes[:'discount_id']
  else
    self.discount_id = nil
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'usage_limit')
    self.usage_limit = attributes[:'usage_limit']
  else
    self.usage_limit = nil
  end

  if attributes.key?(:'times_used')
    self.times_used = attributes[:'times_used']
  else
    self.times_used = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'business_id')
    self.business_id = attributes[:'business_id']
  else
    self.business_id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#amountObject

The discount value. For percentage type, it is in basis points (e.g. 1000 = 10.00%). For fixed_amount type, it is in cents (e.g. 1000 = $10.00).



35
36
37
# File 'lib/solifyn/models/discount.rb', line 35

def amount
  @amount
end

#business_idObject

The unique identifier associated with the business this discount belongs to.



50
51
52
# File 'lib/solifyn/models/discount.rb', line 50

def business_id
  @business_id
end

#codeObject

The unique discount code (e.g. SAVE10) used during checkout.



26
27
28
# File 'lib/solifyn/models/discount.rb', line 26

def code
  @code
end

#created_atObject

Timestamp indicating exactly when the discount was created.



53
54
55
# File 'lib/solifyn/models/discount.rb', line 53

def created_at
  @created_at
end

#discount_idObject

Alias for the unique identifier of the discount.



23
24
25
# File 'lib/solifyn/models/discount.rb', line 23

def discount_id
  @discount_id
end

#expires_atObject

The expiration timestamp after which the discount code is no longer valid.



44
45
46
# File 'lib/solifyn/models/discount.rb', line 44

def expires_at
  @expires_at
end

#idObject

The unique prefix-based identifier of the discount (e.g., ‘disc_cs8f67sd7f6fw3fs`).



20
21
22
# File 'lib/solifyn/models/discount.rb', line 20

def id
  @id
end

#nameObject

The customer-facing name of the discount code (e.g. Summer Sale).



29
30
31
# File 'lib/solifyn/models/discount.rb', line 29

def name
  @name
end

#statusObject

The current status of the discount.



47
48
49
# File 'lib/solifyn/models/discount.rb', line 47

def status
  @status
end

#times_usedObject

The number of times this discount code has been successfully redeemed.



41
42
43
# File 'lib/solifyn/models/discount.rb', line 41

def times_used
  @times_used
end

#typeObject

The discount calculation type: percentage or fixed_amount.



32
33
34
# File 'lib/solifyn/models/discount.rb', line 32

def type
  @type
end

#updated_atObject

Timestamp indicating when the discount was last updated.



56
57
58
# File 'lib/solifyn/models/discount.rb', line 56

def updated_at
  @updated_at
end

#usage_limitObject

Maximum number of times this discount code can be redeemed. Null represents unlimited usage.



38
39
40
# File 'lib/solifyn/models/discount.rb', line 38

def usage_limit
  @usage_limit
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/solifyn/models/discount.rb', line 379

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Solifyn.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/solifyn/models/discount.rb', line 100

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/solifyn/models/discount.rb', line 81

def self.attribute_map
  {
    :'id' => :'id',
    :'discount_id' => :'discount_id',
    :'code' => :'code',
    :'name' => :'name',
    :'type' => :'type',
    :'amount' => :'amount',
    :'usage_limit' => :'usageLimit',
    :'times_used' => :'timesUsed',
    :'expires_at' => :'expiresAt',
    :'status' => :'status',
    :'business_id' => :'businessId',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/solifyn/models/discount.rb', line 355

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
# File 'lib/solifyn/models/discount.rb', line 124

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/solifyn/models/discount.rb', line 105

def self.openapi_types
  {
    :'id' => :'String',
    :'discount_id' => :'String',
    :'code' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'amount' => :'Integer',
    :'usage_limit' => :'Integer',
    :'times_used' => :'Integer',
    :'expires_at' => :'Time',
    :'status' => :'String',
    :'business_id' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/solifyn/models/discount.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      discount_id == o.discount_id &&
      code == o.code &&
      name == o.name &&
      type == o.type &&
      amount == o.amount &&
      usage_limit == o.usage_limit &&
      times_used == o.times_used &&
      expires_at == o.expires_at &&
      status == o.status &&
      business_id == o.business_id &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/solifyn/models/discount.rb', line 450

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


342
343
344
# File 'lib/solifyn/models/discount.rb', line 342

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



348
349
350
# File 'lib/solifyn/models/discount.rb', line 348

def hash
  [id, discount_id, code, name, type, amount, usage_limit, times_used, expires_at, status, business_id, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/solifyn/models/discount.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @discount_id.nil?
    invalid_properties.push('invalid value for "discount_id", discount_id cannot be nil.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @usage_limit.nil?
    invalid_properties.push('invalid value for "usage_limit", usage_limit cannot be nil.')
  end

  if @times_used.nil?
    invalid_properties.push('invalid value for "times_used", times_used cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @business_id.nil?
    invalid_properties.push('invalid value for "business_id", business_id cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



426
427
428
# File 'lib/solifyn/models/discount.rb', line 426

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/solifyn/models/discount.rb', line 432

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



420
421
422
# File 'lib/solifyn/models/discount.rb', line 420

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/solifyn/models/discount.rb', line 279

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @discount_id.nil?
  return false if @code.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["percentage", "fixed_amount"])
  return false unless type_validator.valid?(@type)
  return false if @amount.nil?
  return false if @usage_limit.nil?
  return false if @times_used.nil?
  return false if @expires_at.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["active", "expired"])
  return false unless status_validator.valid?(@status)
  return false if @business_id.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end