Class: Solifyn::EntitlementGrantResponseDto

Inherits:
Object
  • Object
show all
Defined in:
lib/solifyn/models/entitlement_grant_response_dto.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EntitlementGrantResponseDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 138

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Solifyn::EntitlementGrantResponseDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Solifyn::EntitlementGrantResponseDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'business_id')
    self.business_id = attributes[:'business_id']
  else
    self.business_id = nil
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  else
    self.customer_id = nil
  end

  if attributes.key?(:'payment_id')
    self.payment_id = attributes[:'payment_id']
  end

  if attributes.key?(:'product_id')
    self.product_id = attributes[:'product_id']
  else
    self.product_id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'github_repo')
    self.github_repo = attributes[:'github_repo']
  end

  if attributes.key?(:'github_permission')
    self.github_permission = attributes[:'github_permission']
  end

  if attributes.key?(:'github_username')
    self.github_username = attributes[:'github_username']
  end

  if attributes.key?(:'discord_guild_id')
    self.discord_guild_id = attributes[:'discord_guild_id']
  end

  if attributes.key?(:'discord_role_id')
    self.discord_role_id = attributes[:'discord_role_id']
  end

  if attributes.key?(:'discord_username')
    self.discord_username = attributes[:'discord_username']
  end

  if attributes.key?(:'discord_user_id')
    self.discord_user_id = attributes[:'discord_user_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'oauth_url')
    self.oauth_url = attributes[:'oauth_url']
  end

  if attributes.key?(:'error_details')
    self.error_details = attributes[:'error_details']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#business_idObject

The business ID context.



22
23
24
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 22

def business_id
  @business_id
end

#created_atObject

Creation timestamp.



70
71
72
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 70

def created_at
  @created_at
end

#customer_idObject

The customer ID.



25
26
27
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 25

def customer_id
  @customer_id
end

#discord_guild_idObject

Target Discord Guild ID if type is DISCORD.



46
47
48
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 46

def discord_guild_id
  @discord_guild_id
end

#discord_role_idObject

Target Discord Role ID if type is DISCORD.



49
50
51
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 49

def discord_role_id
  @discord_role_id
end

#discord_user_idObject

The connected customer Discord user ID.



55
56
57
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 55

def discord_user_id
  @discord_user_id
end

#discord_usernameObject

The connected customer Discord username.



52
53
54
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 52

def discord_username
  @discord_username
end

#error_detailsObject

Error message if invitation delivery failed.



64
65
66
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 64

def error_details
  @error_details
end

#github_permissionObject

GitHub access permission level if type is GITHUB.



40
41
42
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 40

def github_permission
  @github_permission
end

#github_repoObject

Target GitHub repository (owner/repo) if type is GITHUB.



37
38
39
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 37

def github_repo
  @github_repo
end

#github_usernameObject

The connected customer GitHub username.



43
44
45
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 43

def github_username
  @github_username
end

#idObject

The unique entitlement grant ID.



19
20
21
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 19

def id
  @id
end

#metadataObject

Platform-specific metadata.



67
68
69
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 67

def 
  @metadata
end

#oauth_urlObject

OAuth URL to redirect the customer to.



61
62
63
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 61

def oauth_url
  @oauth_url
end

#payment_idObject

Associated payment transaction ID.



28
29
30
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 28

def payment_id
  @payment_id
end

#product_idObject

The purchased product ID.



31
32
33
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 31

def product_id
  @product_id
end

#statusObject

Delivery status of the collaborator invite (PENDING, DELIVERED, FAILED, REVOKED).



58
59
60
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 58

def status
  @status
end

#typeObject

The type of entitlement (e.g. GITHUB, DISCORD, TELEGRAM).



34
35
36
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 34

def type
  @type
end

#updated_atObject

Modification timestamp.



73
74
75
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 73

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 364

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Solifyn.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 101

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 76

def self.attribute_map
  {
    :'id' => :'id',
    :'business_id' => :'businessId',
    :'customer_id' => :'customerId',
    :'payment_id' => :'paymentId',
    :'product_id' => :'productId',
    :'type' => :'type',
    :'github_repo' => :'githubRepo',
    :'github_permission' => :'githubPermission',
    :'github_username' => :'githubUsername',
    :'discord_guild_id' => :'discordGuildId',
    :'discord_role_id' => :'discordRoleId',
    :'discord_username' => :'discordUsername',
    :'discord_user_id' => :'discordUserId',
    :'status' => :'status',
    :'oauth_url' => :'oauthUrl',
    :'error_details' => :'errorDetails',
    :'metadata' => :'metadata',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 340

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



131
132
133
134
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 131

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 106

def self.openapi_types
  {
    :'id' => :'String',
    :'business_id' => :'String',
    :'customer_id' => :'String',
    :'payment_id' => :'String',
    :'product_id' => :'String',
    :'type' => :'String',
    :'github_repo' => :'String',
    :'github_permission' => :'String',
    :'github_username' => :'String',
    :'discord_guild_id' => :'String',
    :'discord_role_id' => :'String',
    :'discord_username' => :'String',
    :'discord_user_id' => :'String',
    :'status' => :'String',
    :'oauth_url' => :'String',
    :'error_details' => :'String',
    :'metadata' => :'Object',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      business_id == o.business_id &&
      customer_id == o.customer_id &&
      payment_id == o.payment_id &&
      product_id == o.product_id &&
      type == o.type &&
      github_repo == o.github_repo &&
      github_permission == o.github_permission &&
      github_username == o.github_username &&
      discord_guild_id == o.discord_guild_id &&
      discord_role_id == o.discord_role_id &&
      discord_username == o.discord_username &&
      discord_user_id == o.discord_user_id &&
      status == o.status &&
      oauth_url == o.oauth_url &&
      error_details == o.error_details &&
       == o. &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 435

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


327
328
329
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 327

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



333
334
335
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 333

def hash
  [id, business_id, customer_id, payment_id, product_id, type, github_repo, github_permission, github_username, discord_guild_id, discord_role_id, discord_username, discord_user_id, status, oauth_url, error_details, , created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 246

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @business_id.nil?
    invalid_properties.push('invalid value for "business_id", business_id cannot be nil.')
  end

  if @customer_id.nil?
    invalid_properties.push('invalid value for "customer_id", customer_id cannot be nil.')
  end

  if @product_id.nil?
    invalid_properties.push('invalid value for "product_id", product_id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



411
412
413
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 411

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 417

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



405
406
407
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 405

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/solifyn/models/entitlement_grant_response_dto.rb', line 286

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @business_id.nil?
  return false if @customer_id.nil?
  return false if @product_id.nil?
  return false if @type.nil?
  return false if @status.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end