Class: Solifyn::EntitlementsApi
- Inherits:
-
Object
- Object
- Solifyn::EntitlementsApi
- Defined in:
- lib/solifyn/api/entitlements_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#entitlements_create(create_entitlement_dto, opts = {}) ⇒ EntitlementDetailResponseDto
Create Entitlement Create a new independent access entitlement.
-
#entitlements_create_with_http_info(create_entitlement_dto, opts = {}) ⇒ Array<(EntitlementDetailResponseDto, Integer, Hash)>
Create Entitlement Create a new independent access entitlement.
-
#entitlements_delete(id, opts = {}) ⇒ EntitlementDetailResponseDto
Delete Entitlement Delete an independent entitlement and unlink all mapped products.
-
#entitlements_delete_with_http_info(id, opts = {}) ⇒ Array<(EntitlementDetailResponseDto, Integer, Hash)>
Delete Entitlement Delete an independent entitlement and unlink all mapped products.
-
#entitlements_get(id, opts = {}) ⇒ EntitlementDetailResponseDto
Retrieve Entitlement Retrieve a specific entitlement definition by ID.
-
#entitlements_get_with_http_info(id, opts = {}) ⇒ Array<(EntitlementDetailResponseDto, Integer, Hash)>
Retrieve Entitlement Retrieve a specific entitlement definition by ID.
-
#entitlements_list(opts = {}) ⇒ Array<EntitlementDetailResponseDto>
List Entitlements List all independent entitlements for the active business.
-
#entitlements_list_with_http_info(opts = {}) ⇒ Array<(Array<EntitlementDetailResponseDto>, Integer, Hash)>
List Entitlements List all independent entitlements for the active business.
-
#entitlements_update(id, update_entitlement_dto, opts = {}) ⇒ EntitlementDetailResponseDto
Update Entitlement Update details of an existing independent entitlement.
-
#entitlements_update_with_http_info(id, update_entitlement_dto, opts = {}) ⇒ Array<(EntitlementDetailResponseDto, Integer, Hash)>
Update Entitlement Update details of an existing independent entitlement.
-
#initialize(api_client = ApiClient.default) ⇒ EntitlementsApi
constructor
A new instance of EntitlementsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EntitlementsApi
Returns a new instance of EntitlementsApi.
19 20 21 |
# File 'lib/solifyn/api/entitlements_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/entitlements_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#entitlements_create(create_entitlement_dto, opts = {}) ⇒ EntitlementDetailResponseDto
Create Entitlement Create a new independent access entitlement.
27 28 29 30 |
# File 'lib/solifyn/api/entitlements_api.rb', line 27 def entitlements_create(create_entitlement_dto, opts = {}) data, _status_code, _headers = entitlements_create_with_http_info(create_entitlement_dto, opts) data end |
#entitlements_create_with_http_info(create_entitlement_dto, opts = {}) ⇒ Array<(EntitlementDetailResponseDto, Integer, Hash)>
Create Entitlement Create a new independent access entitlement.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/solifyn/api/entitlements_api.rb', line 37 def entitlements_create_with_http_info(create_entitlement_dto, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementsApi.entitlements_create ...' end # verify the required parameter 'create_entitlement_dto' is set if @api_client.config.client_side_validation && create_entitlement_dto.nil? fail ArgumentError, "Missing the required parameter 'create_entitlement_dto' when calling EntitlementsApi.entitlements_create" end # resource path local_var_path = '/v1/entitlements' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_entitlement_dto) # return_type return_type = opts[:debug_return_type] || 'EntitlementDetailResponseDto' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EntitlementsApi.entitlements_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementsApi#entitlements_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#entitlements_delete(id, opts = {}) ⇒ EntitlementDetailResponseDto
Delete Entitlement Delete an independent entitlement and unlink all mapped products.
95 96 97 98 |
# File 'lib/solifyn/api/entitlements_api.rb', line 95 def entitlements_delete(id, opts = {}) data, _status_code, _headers = entitlements_delete_with_http_info(id, opts) data end |
#entitlements_delete_with_http_info(id, opts = {}) ⇒ Array<(EntitlementDetailResponseDto, Integer, Hash)>
Delete Entitlement Delete an independent entitlement and unlink all mapped products.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/solifyn/api/entitlements_api.rb', line 105 def entitlements_delete_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementsApi.entitlements_delete ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EntitlementsApi.entitlements_delete" end # resource path local_var_path = '/v1/entitlements/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EntitlementDetailResponseDto' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EntitlementsApi.entitlements_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementsApi#entitlements_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#entitlements_get(id, opts = {}) ⇒ EntitlementDetailResponseDto
Retrieve Entitlement Retrieve a specific entitlement definition by ID.
158 159 160 161 |
# File 'lib/solifyn/api/entitlements_api.rb', line 158 def entitlements_get(id, opts = {}) data, _status_code, _headers = entitlements_get_with_http_info(id, opts) data end |
#entitlements_get_with_http_info(id, opts = {}) ⇒ Array<(EntitlementDetailResponseDto, Integer, Hash)>
Retrieve Entitlement Retrieve a specific entitlement definition by ID.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/solifyn/api/entitlements_api.rb', line 168 def entitlements_get_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementsApi.entitlements_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EntitlementsApi.entitlements_get" end # resource path local_var_path = '/v1/entitlements/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EntitlementDetailResponseDto' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EntitlementsApi.entitlements_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementsApi#entitlements_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#entitlements_list(opts = {}) ⇒ Array<EntitlementDetailResponseDto>
List Entitlements List all independent entitlements for the active business.
220 221 222 223 |
# File 'lib/solifyn/api/entitlements_api.rb', line 220 def entitlements_list(opts = {}) data, _status_code, _headers = entitlements_list_with_http_info(opts) data end |
#entitlements_list_with_http_info(opts = {}) ⇒ Array<(Array<EntitlementDetailResponseDto>, Integer, Hash)>
List Entitlements List all independent entitlements for the active business.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/solifyn/api/entitlements_api.rb', line 229 def entitlements_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementsApi.entitlements_list ...' end # resource path local_var_path = '/v1/entitlements' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<EntitlementDetailResponseDto>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EntitlementsApi.entitlements_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementsApi#entitlements_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#entitlements_update(id, update_entitlement_dto, opts = {}) ⇒ EntitlementDetailResponseDto
Update Entitlement Update details of an existing independent entitlement.
279 280 281 282 |
# File 'lib/solifyn/api/entitlements_api.rb', line 279 def entitlements_update(id, update_entitlement_dto, opts = {}) data, _status_code, _headers = entitlements_update_with_http_info(id, update_entitlement_dto, opts) data end |
#entitlements_update_with_http_info(id, update_entitlement_dto, opts = {}) ⇒ Array<(EntitlementDetailResponseDto, Integer, Hash)>
Update Entitlement Update details of an existing independent entitlement.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/solifyn/api/entitlements_api.rb', line 290 def entitlements_update_with_http_info(id, update_entitlement_dto, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EntitlementsApi.entitlements_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EntitlementsApi.entitlements_update" end # verify the required parameter 'update_entitlement_dto' is set if @api_client.config.client_side_validation && update_entitlement_dto.nil? fail ArgumentError, "Missing the required parameter 'update_entitlement_dto' when calling EntitlementsApi.entitlements_update" end # resource path local_var_path = '/v1/entitlements/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_entitlement_dto) # return_type return_type = opts[:debug_return_type] || 'EntitlementDetailResponseDto' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EntitlementsApi.entitlements_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EntitlementsApi#entitlements_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |