Class: Solifyn::GitHubIntegrationApi
- Inherits:
-
Object
- Object
- Solifyn::GitHubIntegrationApi
- Defined in:
- lib/solifyn/api/git_hub_integration_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#github_get_install_url(opts = {}) ⇒ nil
Get GitHub App Installation URL Generates the URL to install the system-wide GitHub App onto the merchant’s GitHub account/org.
-
#github_get_install_url_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get GitHub App Installation URL Generates the URL to install the system-wide GitHub App onto the merchant's GitHub account/org.
-
#github_list_repos(opts = {}) ⇒ Array<GithubReposResponseDto>
List Available GitHub Repositories Retrieves all repositories accessible by the merchant’s installed GitHub App.
-
#github_list_repos_with_http_info(opts = {}) ⇒ Array<(Array<GithubReposResponseDto>, Integer, Hash)>
List Available GitHub Repositories Retrieves all repositories accessible by the merchant's installed GitHub App.
-
#initialize(api_client = ApiClient.default) ⇒ GitHubIntegrationApi
constructor
A new instance of GitHubIntegrationApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ GitHubIntegrationApi
Returns a new instance of GitHubIntegrationApi.
19 20 21 |
# File 'lib/solifyn/api/git_hub_integration_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/git_hub_integration_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#github_get_install_url(opts = {}) ⇒ nil
Get GitHub App Installation URL Generates the URL to install the system-wide GitHub App onto the merchant’s GitHub account/org.
27 28 29 30 |
# File 'lib/solifyn/api/git_hub_integration_api.rb', line 27 def github_get_install_url(opts = {}) github_get_install_url_with_http_info(opts) nil end |
#github_get_install_url_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get GitHub App Installation URL Generates the URL to install the system-wide GitHub App onto the merchant's GitHub account/org.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/solifyn/api/git_hub_integration_api.rb', line 37 def github_get_install_url_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GitHubIntegrationApi.github_get_install_url ...' end # resource path local_var_path = '/v1/github/install' # query parameters query_params = opts[:query_params] || {} query_params[:'productId'] = opts[:'product_id'] if !opts[:'product_id'].nil? # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"GitHubIntegrationApi.github_get_install_url", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GitHubIntegrationApi#github_get_install_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#github_list_repos(opts = {}) ⇒ Array<GithubReposResponseDto>
List Available GitHub Repositories Retrieves all repositories accessible by the merchant’s installed GitHub App.
84 85 86 87 |
# File 'lib/solifyn/api/git_hub_integration_api.rb', line 84 def github_list_repos(opts = {}) data, _status_code, _headers = github_list_repos_with_http_info(opts) data end |
#github_list_repos_with_http_info(opts = {}) ⇒ Array<(Array<GithubReposResponseDto>, Integer, Hash)>
List Available GitHub Repositories Retrieves all repositories accessible by the merchant's installed GitHub App.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/solifyn/api/git_hub_integration_api.rb', line 93 def github_list_repos_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GitHubIntegrationApi.github_list_repos ...' end # resource path local_var_path = '/v1/github/repos' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<GithubReposResponseDto>' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"GitHubIntegrationApi.github_list_repos", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GitHubIntegrationApi#github_list_repos\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |