Class: Solifyn::LicenseKeysClientApi
- Inherits:
-
Object
- Object
- Solifyn::LicenseKeysClientApi
- Defined in:
- lib/solifyn/api/license_keys_client_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LicenseKeysClientApi
constructor
A new instance of LicenseKeysClientApi.
-
#licenses_activate(licenses_activate_request, opts = {}) ⇒ Instance
Activate License Key Register and activate a device or instance for a specific license key.
-
#licenses_activate_with_http_info(licenses_activate_request, opts = {}) ⇒ Array<(Instance, Integer, Hash)>
Activate License Key Register and activate a device or instance for a specific license key.
-
#licenses_deactivate(instance_id, licenses_deactivate_request, opts = {}) ⇒ LicensesDeactivate200Response
Deactivate Instance Deactivate or unregister an active device instance from a license key.
-
#licenses_deactivate_with_http_info(instance_id, licenses_deactivate_request, opts = {}) ⇒ Array<(LicensesDeactivate200Response, Integer, Hash)>
Deactivate Instance Deactivate or unregister an active device instance from a license key.
-
#licenses_instances(license_id, opts = {}) ⇒ Array<Instance>
Get Active Instances List all active devices or server instances linked to a specific license key.
-
#licenses_instances_with_http_info(license_id, opts = {}) ⇒ Array<(Array<Instance>, Integer, Hash)>
Get Active Instances List all active devices or server instances linked to a specific license key.
-
#licenses_verify(licenses_verify_request, opts = {}) ⇒ LicenseValidationResponse
Validate License Key Verify if a software license key is valid, active, and has not exceeded its limits.
-
#licenses_verify_with_http_info(licenses_verify_request, opts = {}) ⇒ Array<(LicenseValidationResponse, Integer, Hash)>
Validate License Key Verify if a software license key is valid, active, and has not exceeded its limits.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LicenseKeysClientApi
Returns a new instance of LicenseKeysClientApi.
19 20 21 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#licenses_activate(licenses_activate_request, opts = {}) ⇒ Instance
Activate License Key Register and activate a device or instance for a specific license key.
27 28 29 30 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 27 def licenses_activate(licenses_activate_request, opts = {}) data, _status_code, _headers = licenses_activate_with_http_info(licenses_activate_request, opts) data end |
#licenses_activate_with_http_info(licenses_activate_request, opts = {}) ⇒ Array<(Instance, Integer, Hash)>
Activate License Key Register and activate a device or instance for a specific license key.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 37 def licenses_activate_with_http_info(licenses_activate_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LicenseKeysClientApi.licenses_activate ...' end # verify the required parameter 'licenses_activate_request' is set if @api_client.config.client_side_validation && licenses_activate_request.nil? fail ArgumentError, "Missing the required parameter 'licenses_activate_request' when calling LicenseKeysClientApi.licenses_activate" end # resource path local_var_path = '/v1/licenses/activate' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(licenses_activate_request) # return_type return_type = opts[:debug_return_type] || 'Instance' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"LicenseKeysClientApi.licenses_activate", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LicenseKeysClientApi#licenses_activate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#licenses_deactivate(instance_id, licenses_deactivate_request, opts = {}) ⇒ LicensesDeactivate200Response
Deactivate Instance Deactivate or unregister an active device instance from a license key.
96 97 98 99 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 96 def licenses_deactivate(instance_id, licenses_deactivate_request, opts = {}) data, _status_code, _headers = licenses_deactivate_with_http_info(instance_id, licenses_deactivate_request, opts) data end |
#licenses_deactivate_with_http_info(instance_id, licenses_deactivate_request, opts = {}) ⇒ Array<(LicensesDeactivate200Response, Integer, Hash)>
Deactivate Instance Deactivate or unregister an active device instance from a license key.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 107 def licenses_deactivate_with_http_info(instance_id, licenses_deactivate_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LicenseKeysClientApi.licenses_deactivate ...' end # verify the required parameter 'instance_id' is set if @api_client.config.client_side_validation && instance_id.nil? fail ArgumentError, "Missing the required parameter 'instance_id' when calling LicenseKeysClientApi.licenses_deactivate" end # verify the required parameter 'licenses_deactivate_request' is set if @api_client.config.client_side_validation && licenses_deactivate_request.nil? fail ArgumentError, "Missing the required parameter 'licenses_deactivate_request' when calling LicenseKeysClientApi.licenses_deactivate" end # resource path local_var_path = '/v1/licenses/deactivate/{instanceId}'.sub('{' + 'instanceId' + '}', CGI.escape(instance_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(licenses_deactivate_request) # return_type return_type = opts[:debug_return_type] || 'LicensesDeactivate200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"LicenseKeysClientApi.licenses_deactivate", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LicenseKeysClientApi#licenses_deactivate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#licenses_instances(license_id, opts = {}) ⇒ Array<Instance>
Get Active Instances List all active devices or server instances linked to a specific license key.
169 170 171 172 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 169 def licenses_instances(license_id, opts = {}) data, _status_code, _headers = licenses_instances_with_http_info(license_id, opts) data end |
#licenses_instances_with_http_info(license_id, opts = {}) ⇒ Array<(Array<Instance>, Integer, Hash)>
Get Active Instances List all active devices or server instances linked to a specific license key.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 179 def licenses_instances_with_http_info(license_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LicenseKeysClientApi.licenses_instances ...' end # verify the required parameter 'license_id' is set if @api_client.config.client_side_validation && license_id.nil? fail ArgumentError, "Missing the required parameter 'license_id' when calling LicenseKeysClientApi.licenses_instances" end # resource path local_var_path = '/v1/licenses/instances/{licenseId}'.sub('{' + 'licenseId' + '}', CGI.escape(license_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Instance>' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"LicenseKeysClientApi.licenses_instances", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LicenseKeysClientApi#licenses_instances\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#licenses_verify(licenses_verify_request, opts = {}) ⇒ LicenseValidationResponse
Validate License Key Verify if a software license key is valid, active, and has not exceeded its limits.
232 233 234 235 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 232 def licenses_verify(licenses_verify_request, opts = {}) data, _status_code, _headers = licenses_verify_with_http_info(licenses_verify_request, opts) data end |
#licenses_verify_with_http_info(licenses_verify_request, opts = {}) ⇒ Array<(LicenseValidationResponse, Integer, Hash)>
Validate License Key Verify if a software license key is valid, active, and has not exceeded its limits.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/solifyn/api/license_keys_client_api.rb', line 242 def licenses_verify_with_http_info(licenses_verify_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LicenseKeysClientApi.licenses_verify ...' end # verify the required parameter 'licenses_verify_request' is set if @api_client.config.client_side_validation && licenses_verify_request.nil? fail ArgumentError, "Missing the required parameter 'licenses_verify_request' when calling LicenseKeysClientApi.licenses_verify" end # resource path local_var_path = '/v1/licenses/verify' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(licenses_verify_request) # return_type return_type = opts[:debug_return_type] || 'LicenseValidationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"LicenseKeysClientApi.licenses_verify", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LicenseKeysClientApi#licenses_verify\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |